# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: cometbft/types/v1/types.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from pyinjective.proto.cometbft.crypto.v1 import proof_pb2 as cometbft_dot_crypto_dot_v1_dot_proof__pb2
from pyinjective.proto.cometbft.types.v1 import validator_pb2 as cometbft_dot_types_dot_v1_dot_validator__pb2
from pyinjective.proto.cometbft.version.v1 import types_pb2 as cometbft_dot_version_dot_v1_dot_types__pb2
from pyinjective.proto.gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1d\x63ometbft/types/v1/types.proto\x12\x11\x63ometbft.types.v1\x1a\x1e\x63ometbft/crypto/v1/proof.proto\x1a!cometbft/types/v1/validator.proto\x1a\x1f\x63ometbft/version/v1/types.proto\x1a\x14gogoproto/gogo.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"9\n\rPartSetHeader\x12\x14\n\x05total\x18\x01 \x01(\rR\x05total\x12\x12\n\x04hash\x18\x02 \x01(\x0cR\x04hash\"i\n\x04Part\x12\x14\n\x05index\x18\x01 \x01(\rR\x05index\x12\x14\n\x05\x62ytes\x18\x02 \x01(\x0cR\x05\x62ytes\x12\x35\n\x05proof\x18\x03 \x01(\x0b\x32\x19.cometbft.crypto.v1.ProofB\x04\xc8\xde\x1f\x00R\x05proof\"m\n\x07\x42lockID\x12\x12\n\x04hash\x18\x01 \x01(\x0cR\x04hash\x12N\n\x0fpart_set_header\x18\x02 \x01(\x0b\x32 .cometbft.types.v1.PartSetHeaderB\x04\xc8\xde\x1f\x00R\rpartSetHeader\"\xe8\x04\n\x06Header\x12>\n\x07version\x18\x01 \x01(\x0b\x32\x1e.cometbft.version.v1.ConsensusB\x04\xc8\xde\x1f\x00R\x07version\x12&\n\x08\x63hain_id\x18\x02 \x01(\tB\x0b\xe2\xde\x1f\x07\x43hainIDR\x07\x63hainId\x12\x16\n\x06height\x18\x03 \x01(\x03R\x06height\x12\x38\n\x04time\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x08\xc8\xde\x1f\x00\x90\xdf\x1f\x01R\x04time\x12\x44\n\rlast_block_id\x18\x05 \x01(\x0b\x32\x1a.cometbft.types.v1.BlockIDB\x04\xc8\xde\x1f\x00R\x0blastBlockId\x12(\n\x10last_commit_hash\x18\x06 \x01(\x0cR\x0elastCommitHash\x12\x1b\n\tdata_hash\x18\x07 \x01(\x0cR\x08\x64\x61taHash\x12\'\n\x0fvalidators_hash\x18\x08 \x01(\x0cR\x0evalidatorsHash\x12\x30\n\x14next_validators_hash\x18\t \x01(\x0cR\x12nextValidatorsHash\x12%\n\x0e\x63onsensus_hash\x18\n \x01(\x0cR\rconsensusHash\x12\x19\n\x08\x61pp_hash\x18\x0b \x01(\x0cR\x07\x61ppHash\x12*\n\x11last_results_hash\x18\x0c \x01(\x0cR\x0flastResultsHash\x12#\n\revidence_hash\x18\r \x01(\x0cR\x0c\x65videnceHash\x12)\n\x10proposer_address\x18\x0e \x01(\x0cR\x0fproposerAddress\"\x18\n\x04\x44\x61ta\x12\x10\n\x03txs\x18\x01 \x03(\x0cR\x03txs\"\xb9\x03\n\x04Vote\x12\x34\n\x04type\x18\x01 \x01(\x0e\x32 .cometbft.types.v1.SignedMsgTypeR\x04type\x12\x16\n\x06height\x18\x02 \x01(\x03R\x06height\x12\x14\n\x05round\x18\x03 \x01(\x05R\x05round\x12\x46\n\x08\x62lock_id\x18\x04 \x01(\x0b\x32\x1a.cometbft.types.v1.BlockIDB\x0f\xc8\xde\x1f\x00\xe2\xde\x1f\x07\x42lockIDR\x07\x62lockId\x12\x42\n\ttimestamp\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x08\xc8\xde\x1f\x00\x90\xdf\x1f\x01R\ttimestamp\x12+\n\x11validator_address\x18\x06 \x01(\x0cR\x10validatorAddress\x12\'\n\x0fvalidator_index\x18\x07 \x01(\x05R\x0evalidatorIndex\x12\x1c\n\tsignature\x18\x08 \x01(\x0cR\tsignature\x12\x1c\n\textension\x18\t \x01(\x0cR\textension\x12/\n\x13\x65xtension_signature\x18\n \x01(\x0cR\x12\x65xtensionSignature\"\xc2\x01\n\x06\x43ommit\x12\x16\n\x06height\x18\x01 \x01(\x03R\x06height\x12\x14\n\x05round\x18\x02 \x01(\x05R\x05round\x12\x46\n\x08\x62lock_id\x18\x03 \x01(\x0b\x32\x1a.cometbft.types.v1.BlockIDB\x0f\xc8\xde\x1f\x00\xe2\xde\x1f\x07\x42lockIDR\x07\x62lockId\x12\x42\n\nsignatures\x18\x04 \x03(\x0b\x32\x1c.cometbft.types.v1.CommitSigB\x04\xc8\xde\x1f\x00R\nsignatures\"\xde\x01\n\tCommitSig\x12\x42\n\rblock_id_flag\x18\x01 \x01(\x0e\x32\x1e.cometbft.types.v1.BlockIDFlagR\x0b\x62lockIdFlag\x12+\n\x11validator_address\x18\x02 \x01(\x0cR\x10validatorAddress\x12\x42\n\ttimestamp\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x08\xc8\xde\x1f\x00\x90\xdf\x1f\x01R\ttimestamp\x12\x1c\n\tsignature\x18\x04 \x01(\x0cR\tsignature\"\xe3\x01\n\x0e\x45xtendedCommit\x12\x16\n\x06height\x18\x01 \x01(\x03R\x06height\x12\x14\n\x05round\x18\x02 \x01(\x05R\x05round\x12\x46\n\x08\x62lock_id\x18\x03 \x01(\x0b\x32\x1a.cometbft.types.v1.BlockIDB\x0f\xc8\xde\x1f\x00\xe2\xde\x1f\x07\x42lockIDR\x07\x62lockId\x12[\n\x13\x65xtended_signatures\x18\x04 \x03(\x0b\x32$.cometbft.types.v1.ExtendedCommitSigB\x04\xc8\xde\x1f\x00R\x12\x65xtendedSignatures\"\xb5\x02\n\x11\x45xtendedCommitSig\x12\x42\n\rblock_id_flag\x18\x01 \x01(\x0e\x32\x1e.cometbft.types.v1.BlockIDFlagR\x0b\x62lockIdFlag\x12+\n\x11validator_address\x18\x02 \x01(\x0cR\x10validatorAddress\x12\x42\n\ttimestamp\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x08\xc8\xde\x1f\x00\x90\xdf\x1f\x01R\ttimestamp\x12\x1c\n\tsignature\x18\x04 \x01(\x0cR\tsignature\x12\x1c\n\textension\x18\x05 \x01(\x0cR\textension\x12/\n\x13\x65xtension_signature\x18\x06 \x01(\x0cR\x12\x65xtensionSignature\"\xb5\x02\n\x08Proposal\x12\x34\n\x04type\x18\x01 \x01(\x0e\x32 .cometbft.types.v1.SignedMsgTypeR\x04type\x12\x16\n\x06height\x18\x02 \x01(\x03R\x06height\x12\x14\n\x05round\x18\x03 \x01(\x05R\x05round\x12\x1b\n\tpol_round\x18\x04 \x01(\x05R\x08polRound\x12\x46\n\x08\x62lock_id\x18\x05 \x01(\x0b\x32\x1a.cometbft.types.v1.BlockIDB\x0f\xc8\xde\x1f\x00\xe2\xde\x1f\x07\x42lockIDR\x07\x62lockId\x12\x42\n\ttimestamp\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x08\xc8\xde\x1f\x00\x90\xdf\x1f\x01R\ttimestamp\x12\x1c\n\tsignature\x18\x07 \x01(\x0cR\tsignature\"t\n\x0cSignedHeader\x12\x31\n\x06header\x18\x01 \x01(\x0b\x32\x19.cometbft.types.v1.HeaderR\x06header\x12\x31\n\x06\x63ommit\x18\x02 \x01(\x0b\x32\x19.cometbft.types.v1.CommitR\x06\x63ommit\"\x98\x01\n\nLightBlock\x12\x44\n\rsigned_header\x18\x01 \x01(\x0b\x32\x1f.cometbft.types.v1.SignedHeaderR\x0csignedHeader\x12\x44\n\rvalidator_set\x18\x02 \x01(\x0b\x32\x1f.cometbft.types.v1.ValidatorSetR\x0cvalidatorSet\"\xc4\x01\n\tBlockMeta\x12\x46\n\x08\x62lock_id\x18\x01 \x01(\x0b\x32\x1a.cometbft.types.v1.BlockIDB\x0f\xc8\xde\x1f\x00\xe2\xde\x1f\x07\x42lockIDR\x07\x62lockId\x12\x1d\n\nblock_size\x18\x02 \x01(\x03R\tblockSize\x12\x37\n\x06header\x18\x03 \x01(\x0b\x32\x19.cometbft.types.v1.HeaderB\x04\xc8\xde\x1f\x00R\x06header\x12\x17\n\x07num_txs\x18\x04 \x01(\x03R\x06numTxs\"k\n\x07TxProof\x12\x1b\n\troot_hash\x18\x01 \x01(\x0cR\x08rootHash\x12\x12\n\x04\x64\x61ta\x18\x02 \x01(\x0cR\x04\x64\x61ta\x12/\n\x05proof\x18\x03 \x01(\x0b\x32\x19.cometbft.crypto.v1.ProofR\x05proof*\xd7\x01\n\rSignedMsgType\x12,\n\x17SIGNED_MSG_TYPE_UNKNOWN\x10\x00\x1a\x0f\x8a\x9d \x0bUnknownType\x12,\n\x17SIGNED_MSG_TYPE_PREVOTE\x10\x01\x1a\x0f\x8a\x9d \x0bPrevoteType\x12\x30\n\x19SIGNED_MSG_TYPE_PRECOMMIT\x10\x02\x1a\x11\x8a\x9d \rPrecommitType\x12.\n\x18SIGNED_MSG_TYPE_PROPOSAL\x10 \x1a\x10\x8a\x9d \x0cProposalType\x1a\x08\x88\xa3\x1e\x00\xa8\xa4\x1e\x01\x42\xbd\x01\n\x15\x63om.cometbft.types.v1B\nTypesProtoP\x01Z2github.com/cometbft/cometbft/api/cometbft/types/v1\xa2\x02\x03\x43TX\xaa\x02\x11\x43ometbft.Types.V1\xca\x02\x11\x43ometbft\\Types\\V1\xe2\x02\x1d\x43ometbft\\Types\\V1\\GPBMetadata\xea\x02\x13\x43ometbft::Types::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'cometbft.types.v1.types_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\025com.cometbft.types.v1B\nTypesProtoP\001Z2github.com/cometbft/cometbft/api/cometbft/types/v1\242\002\003CTX\252\002\021Cometbft.Types.V1\312\002\021Cometbft\\Types\\V1\342\002\035Cometbft\\Types\\V1\\GPBMetadata\352\002\023Cometbft::Types::V1'
  _globals['_SIGNEDMSGTYPE']._loaded_options = None
  _globals['_SIGNEDMSGTYPE']._serialized_options = b'\210\243\036\000\250\244\036\001'
  _globals['_SIGNEDMSGTYPE'].values_by_name["SIGNED_MSG_TYPE_UNKNOWN"]._loaded_options = None
  _globals['_SIGNEDMSGTYPE'].values_by_name["SIGNED_MSG_TYPE_UNKNOWN"]._serialized_options = b'\212\235 \013UnknownType'
  _globals['_SIGNEDMSGTYPE'].values_by_name["SIGNED_MSG_TYPE_PREVOTE"]._loaded_options = None
  _globals['_SIGNEDMSGTYPE'].values_by_name["SIGNED_MSG_TYPE_PREVOTE"]._serialized_options = b'\212\235 \013PrevoteType'
  _globals['_SIGNEDMSGTYPE'].values_by_name["SIGNED_MSG_TYPE_PRECOMMIT"]._loaded_options = None
  _globals['_SIGNEDMSGTYPE'].values_by_name["SIGNED_MSG_TYPE_PRECOMMIT"]._serialized_options = b'\212\235 \rPrecommitType'
  _globals['_SIGNEDMSGTYPE'].values_by_name["SIGNED_MSG_TYPE_PROPOSAL"]._loaded_options = None
  _globals['_SIGNEDMSGTYPE'].values_by_name["SIGNED_MSG_TYPE_PROPOSAL"]._serialized_options = b'\212\235 \014ProposalType'
  _globals['_PART'].fields_by_name['proof']._loaded_options = None
  _globals['_PART'].fields_by_name['proof']._serialized_options = b'\310\336\037\000'
  _globals['_BLOCKID'].fields_by_name['part_set_header']._loaded_options = None
  _globals['_BLOCKID'].fields_by_name['part_set_header']._serialized_options = b'\310\336\037\000'
  _globals['_HEADER'].fields_by_name['version']._loaded_options = None
  _globals['_HEADER'].fields_by_name['version']._serialized_options = b'\310\336\037\000'
  _globals['_HEADER'].fields_by_name['chain_id']._loaded_options = None
  _globals['_HEADER'].fields_by_name['chain_id']._serialized_options = b'\342\336\037\007ChainID'
  _globals['_HEADER'].fields_by_name['time']._loaded_options = None
  _globals['_HEADER'].fields_by_name['time']._serialized_options = b'\310\336\037\000\220\337\037\001'
  _globals['_HEADER'].fields_by_name['last_block_id']._loaded_options = None
  _globals['_HEADER'].fields_by_name['last_block_id']._serialized_options = b'\310\336\037\000'
  _globals['_VOTE'].fields_by_name['block_id']._loaded_options = None
  _globals['_VOTE'].fields_by_name['block_id']._serialized_options = b'\310\336\037\000\342\336\037\007BlockID'
  _globals['_VOTE'].fields_by_name['timestamp']._loaded_options = None
  _globals['_VOTE'].fields_by_name['timestamp']._serialized_options = b'\310\336\037\000\220\337\037\001'
  _globals['_COMMIT'].fields_by_name['block_id']._loaded_options = None
  _globals['_COMMIT'].fields_by_name['block_id']._serialized_options = b'\310\336\037\000\342\336\037\007BlockID'
  _globals['_COMMIT'].fields_by_name['signatures']._loaded_options = None
  _globals['_COMMIT'].fields_by_name['signatures']._serialized_options = b'\310\336\037\000'
  _globals['_COMMITSIG'].fields_by_name['timestamp']._loaded_options = None
  _globals['_COMMITSIG'].fields_by_name['timestamp']._serialized_options = b'\310\336\037\000\220\337\037\001'
  _globals['_EXTENDEDCOMMIT'].fields_by_name['block_id']._loaded_options = None
  _globals['_EXTENDEDCOMMIT'].fields_by_name['block_id']._serialized_options = b'\310\336\037\000\342\336\037\007BlockID'
  _globals['_EXTENDEDCOMMIT'].fields_by_name['extended_signatures']._loaded_options = None
  _globals['_EXTENDEDCOMMIT'].fields_by_name['extended_signatures']._serialized_options = b'\310\336\037\000'
  _globals['_EXTENDEDCOMMITSIG'].fields_by_name['timestamp']._loaded_options = None
  _globals['_EXTENDEDCOMMITSIG'].fields_by_name['timestamp']._serialized_options = b'\310\336\037\000\220\337\037\001'
  _globals['_PROPOSAL'].fields_by_name['block_id']._loaded_options = None
  _globals['_PROPOSAL'].fields_by_name['block_id']._serialized_options = b'\310\336\037\000\342\336\037\007BlockID'
  _globals['_PROPOSAL'].fields_by_name['timestamp']._loaded_options = None
  _globals['_PROPOSAL'].fields_by_name['timestamp']._serialized_options = b'\310\336\037\000\220\337\037\001'
  _globals['_BLOCKMETA'].fields_by_name['block_id']._loaded_options = None
  _globals['_BLOCKMETA'].fields_by_name['block_id']._serialized_options = b'\310\336\037\000\342\336\037\007BlockID'
  _globals['_BLOCKMETA'].fields_by_name['header']._loaded_options = None
  _globals['_BLOCKMETA'].fields_by_name['header']._serialized_options = b'\310\336\037\000'
  _globals['_SIGNEDMSGTYPE']._serialized_start=3431
  _globals['_SIGNEDMSGTYPE']._serialized_end=3646
  _globals['_PARTSETHEADER']._serialized_start=207
  _globals['_PARTSETHEADER']._serialized_end=264
  _globals['_PART']._serialized_start=266
  _globals['_PART']._serialized_end=371
  _globals['_BLOCKID']._serialized_start=373
  _globals['_BLOCKID']._serialized_end=482
  _globals['_HEADER']._serialized_start=485
  _globals['_HEADER']._serialized_end=1101
  _globals['_DATA']._serialized_start=1103
  _globals['_DATA']._serialized_end=1127
  _globals['_VOTE']._serialized_start=1130
  _globals['_VOTE']._serialized_end=1571
  _globals['_COMMIT']._serialized_start=1574
  _globals['_COMMIT']._serialized_end=1768
  _globals['_COMMITSIG']._serialized_start=1771
  _globals['_COMMITSIG']._serialized_end=1993
  _globals['_EXTENDEDCOMMIT']._serialized_start=1996
  _globals['_EXTENDEDCOMMIT']._serialized_end=2223
  _globals['_EXTENDEDCOMMITSIG']._serialized_start=2226
  _globals['_EXTENDEDCOMMITSIG']._serialized_end=2535
  _globals['_PROPOSAL']._serialized_start=2538
  _globals['_PROPOSAL']._serialized_end=2847
  _globals['_SIGNEDHEADER']._serialized_start=2849
  _globals['_SIGNEDHEADER']._serialized_end=2965
  _globals['_LIGHTBLOCK']._serialized_start=2968
  _globals['_LIGHTBLOCK']._serialized_end=3120
  _globals['_BLOCKMETA']._serialized_start=3123
  _globals['_BLOCKMETA']._serialized_end=3319
  _globals['_TXPROOF']._serialized_start=3321
  _globals['_TXPROOF']._serialized_end=3428
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ibc/core/connection/v1/genesis.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from pyinjective.proto.gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from pyinjective.proto.ibc.core.connection.v1 import connection_pb2 as ibc_dot_core_dot_connection_dot_v1_dot_connection__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n$ibc/core/connection/v1/genesis.proto\x12\x16ibc.core.connection.v1\x1a\x14gogoproto/gogo.proto\x1a\'ibc/core/connection/v1/connection.proto\"\xc3\x02\n\x0cGenesisState\x12T\n\x0b\x63onnections\x18\x01 \x03(\x0b\x32,.ibc.core.connection.v1.IdentifiedConnectionB\x04\xc8\xde\x1f\x00R\x0b\x63onnections\x12\x65\n\x17\x63lient_connection_paths\x18\x02 \x03(\x0b\x32\'.ibc.core.connection.v1.ConnectionPathsB\x04\xc8\xde\x1f\x00R\x15\x63lientConnectionPaths\x12\x38\n\x18next_connection_sequence\x18\x03 \x01(\x04R\x16nextConnectionSequence\x12<\n\x06params\x18\x04 \x01(\x0b\x32\x1e.ibc.core.connection.v1.ParamsB\x04\xc8\xde\x1f\x00R\x06paramsB\xe3\x01\n\x1a\x63om.ibc.core.connection.v1B\x0cGenesisProtoP\x01Z<github.com/cosmos/ibc-go/v8/modules/core/03-connection/types\xa2\x02\x03ICC\xaa\x02\x16Ibc.Core.Connection.V1\xca\x02\x16Ibc\\Core\\Connection\\V1\xe2\x02\"Ibc\\Core\\Connection\\V1\\GPBMetadata\xea\x02\x19Ibc::Core::Connection::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ibc.core.connection.v1.genesis_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\032com.ibc.core.connection.v1B\014GenesisProtoP\001Z<github.com/cosmos/ibc-go/v8/modules/core/03-connection/types\242\002\003ICC\252\002\026Ibc.Core.Connection.V1\312\002\026Ibc\\Core\\Connection\\V1\342\002\"Ibc\\Core\\Connection\\V1\\GPBMetadata\352\002\031Ibc::Core::Connection::V1'
  _globals['_GENESISSTATE'].fields_by_name['connections']._loaded_options = None
  _globals['_GENESISSTATE'].fields_by_name['connections']._serialized_options = b'\310\336\037\000'
  _globals['_GENESISSTATE'].fields_by_name['client_connection_paths']._loaded_options = None
  _globals['_GENESISSTATE'].fields_by_name['client_connection_paths']._serialized_options = b'\310\336\037\000'
  _globals['_GENESISSTATE'].fields_by_name['params']._loaded_options = None
  _globals['_GENESISSTATE'].fields_by_name['params']._serialized_options = b'\310\336\037\000'
  _globals['_GENESISSTATE']._serialized_start=128
  _globals['_GENESISSTATE']._serialized_end=451
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: cosmos/nft/v1beta1/genesis.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from pyinjective.proto.cosmos.nft.v1beta1 import nft_pb2 as cosmos_dot_nft_dot_v1beta1_dot_nft__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n cosmos/nft/v1beta1/genesis.proto\x12\x12\x63osmos.nft.v1beta1\x1a\x1c\x63osmos/nft/v1beta1/nft.proto\"x\n\x0cGenesisState\x12\x33\n\x07\x63lasses\x18\x01 \x03(\x0b\x32\x19.cosmos.nft.v1beta1.ClassR\x07\x63lasses\x12\x33\n\x07\x65ntries\x18\x02 \x03(\x0b\x32\x19.cosmos.nft.v1beta1.EntryR\x07\x65ntries\"J\n\x05\x45ntry\x12\x14\n\x05owner\x18\x01 \x01(\tR\x05owner\x12+\n\x04nfts\x18\x02 \x03(\x0b\x32\x17.cosmos.nft.v1beta1.NFTR\x04nftsB\xa4\x01\n\x16\x63om.cosmos.nft.v1beta1B\x0cGenesisProtoP\x01Z\x12\x63osmossdk.io/x/nft\xa2\x02\x03\x43NX\xaa\x02\x12\x43osmos.Nft.V1beta1\xca\x02\x12\x43osmos\\Nft\\V1beta1\xe2\x02\x1e\x43osmos\\Nft\\V1beta1\\GPBMetadata\xea\x02\x14\x43osmos::Nft::V1beta1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'cosmos.nft.v1beta1.genesis_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\026com.cosmos.nft.v1beta1B\014GenesisProtoP\001Z\022cosmossdk.io/x/nft\242\002\003CNX\252\002\022Cosmos.Nft.V1beta1\312\002\022Cosmos\\Nft\\V1beta1\342\002\036Cosmos\\Nft\\V1beta1\\GPBMetadata\352\002\024Cosmos::Nft::V1beta1'
  _globals['_GENESISSTATE']._serialized_start=86
  _globals['_GENESISSTATE']._serialized_end=206
  _globals['_ENTRY']._serialized_start=208
  _globals['_ENTRY']._serialized_end=282
# @@protoc_insertion_point(module_scope)



from google.protobuf import any_pb2

from pyinjective.proto.injective.types.v1beta1 import account_pb2 as account_pb


class Account:
    def __init__(
        self,
        address: str,
        pub_key_type_url: str,
        pub_key_value: bytes,
        account_number: int,
        sequence: int,
        code_hash: str,
    ):
        super().__init__()
        self.address = address
        self.pub_key_type_url = pub_key_type_url
        self.pub_key_value = pub_key_value
        self.account_number = account_number
        self.sequence = sequence
        self.code_hash = code_hash

    @classmethod
    def from_proto(cls, proto_account: any_pb2.Any):
        eth_account = account_pb.EthAccount()
        proto_account.Unpack(eth_account)
        pub_key_type_url = None
        pub_key_value = None

        if eth_account.base_account.pub_key is not None:
            pub_key_type_url = eth_account.base_account.pub_key.type_url
            pub_key_value = eth_account.base_account.pub_key.value

        return cls(
            address=eth_account.base_account.address,
            pub_key_type_url=pub_key_type_url,
            pub_key_value=pub_key_value,
            account_number=eth_account.base_account.account_number,
            sequence=eth_account.base_account.sequence,
            code_hash=f"0x{eth_account.code_hash.hex()}",
        )



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from pyinjective.proto.injective.oracle.v1beta1 import query_pb2 as injective_dot_oracle_dot_v1beta1_dot_query__pb2


class QueryStub(object):
    """Query defines the gRPC querier service.
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.Params = channel.unary_unary(
                '/injective.oracle.v1beta1.Query/Params',
                request_serializer=injective_dot_oracle_dot_v1beta1_dot_query__pb2.QueryParamsRequest.SerializeToString,
                response_deserializer=injective_dot_oracle_dot_v1beta1_dot_query__pb2.QueryParamsResponse.FromString,
                _registered_method=True)
        self.BandRelayers = channel.unary_unary(
                '/injective.oracle.v1beta1.Query/BandRelayers',
                request_serializer=injective_dot_oracle_dot_v1beta1_dot_query__pb2.QueryBandRelayersRequest.SerializeToString,
                response_deserializer=injective_dot_oracle_dot_v1beta1_dot_query__pb2.QueryBandRelayersResponse.FromString,
                _registered_method=True)
        self.BandPriceStates = channel.unary_unary(
                '/injective.oracle.v1beta1.Query/BandPriceStates',
                request_serializer=injective_dot_oracle_dot_v1beta1_dot_query__pb2.QueryBandPriceStatesRequest.SerializeToString,
                response_deserializer=injective_dot_oracle_dot_v1beta1_dot_query__pb2.QueryBandPriceStatesResponse.FromString,
                _registered_method=True)
        self.BandIBCPriceStates = channel.unary_unary(
                '/injective.oracle.v1beta1.Query/BandIBCPriceStates',
                request_serializer=injective_dot_oracle_dot_v1beta1_dot_query__pb2.QueryBandIBCPriceStatesRequest.SerializeToString,
                response_deserializer=injective_dot_oracle_dot_v1beta1_dot_query__pb2.QueryBandIBCPriceStatesResponse.FromString,
                _registered_method=True)
        self.PriceFeedPriceStates = channel.unary_unary(
                '/injective.oracle.v1beta1.Query/PriceFeedPriceStates',
                request_serializer=injective_dot_oracle_dot_v1beta1_dot_query__pb2.QueryPriceFeedPriceStatesRequest.SerializeToString,
                response_deserializer=injective_dot_oracle_dot_v1beta1_dot_query__pb2.QueryPriceFeedPriceStatesResponse.FromString,
                _registered_method=True)
        self.CoinbasePriceStates = channel.unary_unary(
                '/injective.oracle.v1beta1.Query/CoinbasePriceStates',
                request_serializer=injective_dot_oracle_dot_v1beta1_dot_query__pb2.QueryCoinbasePriceStatesRequest.SerializeToString,
                response_deserializer=injective_dot_oracle_dot_v1beta1_dot_query__pb2.QueryCoinbasePriceStatesResponse.FromString,
                _registered_method=True)
        self.PythPriceStates = channel.unary_unary(
                '/injective.oracle.v1beta1.Query/PythPriceStates',
                request_serializer=injective_dot_oracle_dot_v1beta1_dot_query__pb2.QueryPythPriceStatesRequest.SerializeToString,
                response_deserializer=injective_dot_oracle_dot_v1beta1_dot_query__pb2.QueryPythPriceStatesResponse.FromString,
                _registered_method=True)
        self.StorkPriceStates = channel.unary_unary(
                '/injective.oracle.v1beta1.Query/StorkPriceStates',
                request_serializer=injective_dot_oracle_dot_v1beta1_dot_query__pb2.QueryStorkPriceStatesRequest.SerializeToString,
                response_deserializer=injective_dot_oracle_dot_v1beta1_dot_query__pb2.QueryStorkPriceStatesResponse.FromString,
                _registered_method=True)
        self.StorkPublishers = channel.unary_unary(
                '/injective.oracle.v1beta1.Query/StorkPublishers',
                request_serializer=injective_dot_oracle_dot_v1beta1_dot_query__pb2.QueryStorkPublishersRequest.SerializeToString,
                response_deserializer=injective_dot_oracle_dot_v1beta1_dot_query__pb2.QueryStorkPublishersResponse.FromString,
                _registered_method=True)
        self.ProviderPriceState = channel.unary_unary(
                '/injective.oracle.v1beta1.Query/ProviderPriceState',
                request_serializer=injective_dot_oracle_dot_v1beta1_dot_query__pb2.QueryProviderPriceStateRequest.SerializeToString,
                response_deserializer=injective_dot_oracle_dot_v1beta1_dot_query__pb2.QueryProviderPriceStateResponse.FromString,
                _registered_method=True)
        self.OracleModuleState = channel.unary_unary(
                '/injective.oracle.v1beta1.Query/OracleModuleState',
                request_serializer=injective_dot_oracle_dot_v1beta1_dot_query__pb2.QueryModuleStateRequest.SerializeToString,
                response_deserializer=injective_dot_oracle_dot_v1beta1_dot_query__pb2.QueryModuleStateResponse.FromString,
                _registered_method=True)
        self.HistoricalPriceRecords = channel.unary_unary(
                '/injective.oracle.v1beta1.Query/HistoricalPriceRecords',
                request_serializer=injective_dot_oracle_dot_v1beta1_dot_query__pb2.QueryHistoricalPriceRecordsRequest.SerializeToString,
                response_deserializer=injective_dot_oracle_dot_v1beta1_dot_query__pb2.QueryHistoricalPriceRecordsResponse.FromString,
                _registered_method=True)
        self.OracleVolatility = channel.unary_unary(
                '/injective.oracle.v1beta1.Query/OracleVolatility',
                request_serializer=injective_dot_oracle_dot_v1beta1_dot_query__pb2.QueryOracleVolatilityRequest.SerializeToString,
                response_deserializer=injective_dot_oracle_dot_v1beta1_dot_query__pb2.QueryOracleVolatilityResponse.FromString,
                _registered_method=True)
        self.OracleProvidersInfo = channel.unary_unary(
                '/injective.oracle.v1beta1.Query/OracleProvidersInfo',
                request_serializer=injective_dot_oracle_dot_v1beta1_dot_query__pb2.QueryOracleProvidersInfoRequest.SerializeToString,
                response_deserializer=injective_dot_oracle_dot_v1beta1_dot_query__pb2.QueryOracleProvidersInfoResponse.FromString,
                _registered_method=True)
        self.OracleProviderPrices = channel.unary_unary(
                '/injective.oracle.v1beta1.Query/OracleProviderPrices',
                request_serializer=injective_dot_oracle_dot_v1beta1_dot_query__pb2.QueryOracleProviderPricesRequest.SerializeToString,
                response_deserializer=injective_dot_oracle_dot_v1beta1_dot_query__pb2.QueryOracleProviderPricesResponse.FromString,
                _registered_method=True)
        self.OraclePrice = channel.unary_unary(
                '/injective.oracle.v1beta1.Query/OraclePrice',
                request_serializer=injective_dot_oracle_dot_v1beta1_dot_query__pb2.QueryOraclePriceRequest.SerializeToString,
                response_deserializer=injective_dot_oracle_dot_v1beta1_dot_query__pb2.QueryOraclePriceResponse.FromString,
                _registered_method=True)
        self.PythPrice = channel.unary_unary(
                '/injective.oracle.v1beta1.Query/PythPrice',
                request_serializer=injective_dot_oracle_dot_v1beta1_dot_query__pb2.QueryPythPriceRequest.SerializeToString,
                response_deserializer=injective_dot_oracle_dot_v1beta1_dot_query__pb2.QueryPythPriceResponse.FromString,
                _registered_method=True)


class QueryServicer(object):
    """Query defines the gRPC querier service.
    """

    def Params(self, request, context):
        """Retrieves oracle params
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def BandRelayers(self, request, context):
        """Retrieves the band relayers
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def BandPriceStates(self, request, context):
        """Retrieves the state for all band price feeds
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def BandIBCPriceStates(self, request, context):
        """Retrieves the state for all band ibc price feeds
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def PriceFeedPriceStates(self, request, context):
        """Retrieves the state for all price feeds
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CoinbasePriceStates(self, request, context):
        """Retrieves the state for all coinbase price feeds
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def PythPriceStates(self, request, context):
        """Retrieves the state for all pyth price feeds
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def StorkPriceStates(self, request, context):
        """Retrieves the state for all stork price feeds
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def StorkPublishers(self, request, context):
        """Retrieves all stork publishers
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ProviderPriceState(self, request, context):
        """Retrieves the state for all provider price feeds
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def OracleModuleState(self, request, context):
        """Retrieves the entire oracle module's state
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def HistoricalPriceRecords(self, request, context):
        """Retrieves historical price records for a given OracleType and Symbol
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def OracleVolatility(self, request, context):
        """Retrieves mixed volatility value for the specified pair of base/quote
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def OracleProvidersInfo(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def OracleProviderPrices(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def OraclePrice(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def PythPrice(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_QueryServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'Params': grpc.unary_unary_rpc_method_handler(
                    servicer.Params,
                    request_deserializer=injective_dot_oracle_dot_v1beta1_dot_query__pb2.QueryParamsRequest.FromString,
                    response_serializer=injective_dot_oracle_dot_v1beta1_dot_query__pb2.QueryParamsResponse.SerializeToString,
            ),
            'BandRelayers': grpc.unary_unary_rpc_method_handler(
                    servicer.BandRelayers,
                    request_deserializer=injective_dot_oracle_dot_v1beta1_dot_query__pb2.QueryBandRelayersRequest.FromString,
                    response_serializer=injective_dot_oracle_dot_v1beta1_dot_query__pb2.QueryBandRelayersResponse.SerializeToString,
            ),
            'BandPriceStates': grpc.unary_unary_rpc_method_handler(
                    servicer.BandPriceStates,
                    request_deserializer=injective_dot_oracle_dot_v1beta1_dot_query__pb2.QueryBandPriceStatesRequest.FromString,
                    response_serializer=injective_dot_oracle_dot_v1beta1_dot_query__pb2.QueryBandPriceStatesResponse.SerializeToString,
            ),
            'BandIBCPriceStates': grpc.unary_unary_rpc_method_handler(
                    servicer.BandIBCPriceStates,
                    request_deserializer=injective_dot_oracle_dot_v1beta1_dot_query__pb2.QueryBandIBCPriceStatesRequest.FromString,
                    response_serializer=injective_dot_oracle_dot_v1beta1_dot_query__pb2.QueryBandIBCPriceStatesResponse.SerializeToString,
            ),
            'PriceFeedPriceStates': grpc.unary_unary_rpc_method_handler(
                    servicer.PriceFeedPriceStates,
                    request_deserializer=injective_dot_oracle_dot_v1beta1_dot_query__pb2.QueryPriceFeedPriceStatesRequest.FromString,
                    response_serializer=injective_dot_oracle_dot_v1beta1_dot_query__pb2.QueryPriceFeedPriceStatesResponse.SerializeToString,
            ),
            'CoinbasePriceStates': grpc.unary_unary_rpc_method_handler(
                    servicer.CoinbasePriceStates,
                    request_deserializer=injective_dot_oracle_dot_v1beta1_dot_query__pb2.QueryCoinbasePriceStatesRequest.FromString,
                    response_serializer=injective_dot_oracle_dot_v1beta1_dot_query__pb2.QueryCoinbasePriceStatesResponse.SerializeToString,
            ),
            'PythPriceStates': grpc.unary_unary_rpc_method_handler(
                    servicer.PythPriceStates,
                    request_deserializer=injective_dot_oracle_dot_v1beta1_dot_query__pb2.QueryPythPriceStatesRequest.FromString,
                    response_serializer=injective_dot_oracle_dot_v1beta1_dot_query__pb2.QueryPythPriceStatesResponse.SerializeToString,
            ),
            'StorkPriceStates': grpc.unary_unary_rpc_method_handler(
                    servicer.StorkPriceStates,
                    request_deserializer=injective_dot_oracle_dot_v1beta1_dot_query__pb2.QueryStorkPriceStatesRequest.FromString,
                    response_serializer=injective_dot_oracle_dot_v1beta1_dot_query__pb2.QueryStorkPriceStatesResponse.SerializeToString,
            ),
            'StorkPublishers': grpc.unary_unary_rpc_method_handler(
                    servicer.StorkPublishers,
                    request_deserializer=injective_dot_oracle_dot_v1beta1_dot_query__pb2.QueryStorkPublishersRequest.FromString,
                    response_serializer=injective_dot_oracle_dot_v1beta1_dot_query__pb2.QueryStorkPublishersResponse.SerializeToString,
            ),
            'ProviderPriceState': grpc.unary_unary_rpc_method_handler(
                    servicer.ProviderPriceState,
                    request_deserializer=injective_dot_oracle_dot_v1beta1_dot_query__pb2.QueryProviderPriceStateRequest.FromString,
                    response_serializer=injective_dot_oracle_dot_v1beta1_dot_query__pb2.QueryProviderPriceStateResponse.SerializeToString,
            ),
            'OracleModuleState': grpc.unary_unary_rpc_method_handler(
                    servicer.OracleModuleState,
                    request_deserializer=injective_dot_oracle_dot_v1beta1_dot_query__pb2.QueryModuleStateRequest.FromString,
                    response_serializer=injective_dot_oracle_dot_v1beta1_dot_query__pb2.QueryModuleStateResponse.SerializeToString,
            ),
            'HistoricalPriceRecords': grpc.unary_unary_rpc_method_handler(
                    servicer.HistoricalPriceRecords,
                    request_deserializer=injective_dot_oracle_dot_v1beta1_dot_query__pb2.QueryHistoricalPriceRecordsRequest.FromString,
                    response_serializer=injective_dot_oracle_dot_v1beta1_dot_query__pb2.QueryHistoricalPriceRecordsResponse.SerializeToString,
            ),
            'OracleVolatility': grpc.unary_unary_rpc_method_handler(
                    servicer.OracleVolatility,
                    request_deserializer=injective_dot_oracle_dot_v1beta1_dot_query__pb2.QueryOracleVolatilityRequest.FromString,
                    response_serializer=injective_dot_oracle_dot_v1beta1_dot_query__pb2.QueryOracleVolatilityResponse.SerializeToString,
            ),
            'OracleProvidersInfo': grpc.unary_unary_rpc_method_handler(
                    servicer.OracleProvidersInfo,
                    request_deserializer=injective_dot_oracle_dot_v1beta1_dot_query__pb2.QueryOracleProvidersInfoRequest.FromString,
                    response_serializer=injective_dot_oracle_dot_v1beta1_dot_query__pb2.QueryOracleProvidersInfoResponse.SerializeToString,
            ),
            'OracleProviderPrices': grpc.unary_unary_rpc_method_handler(
                    servicer.OracleProviderPrices,
                    request_deserializer=injective_dot_oracle_dot_v1beta1_dot_query__pb2.QueryOracleProviderPricesRequest.FromString,
                    response_serializer=injective_dot_oracle_dot_v1beta1_dot_query__pb2.QueryOracleProviderPricesResponse.SerializeToString,
            ),
            'OraclePrice': grpc.unary_unary_rpc_method_handler(
                    servicer.OraclePrice,
                    request_deserializer=injective_dot_oracle_dot_v1beta1_dot_query__pb2.QueryOraclePriceRequest.FromString,
                    response_serializer=injective_dot_oracle_dot_v1beta1_dot_query__pb2.QueryOraclePriceResponse.SerializeToString,
            ),
            'PythPrice': grpc.unary_unary_rpc_method_handler(
                    servicer.PythPrice,
                    request_deserializer=injective_dot_oracle_dot_v1beta1_dot_query__pb2.QueryPythPriceRequest.FromString,
                    response_serializer=injective_dot_oracle_dot_v1beta1_dot_query__pb2.QueryPythPriceResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'injective.oracle.v1beta1.Query', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))
    server.add_registered_method_handlers('injective.oracle.v1beta1.Query', rpc_method_handlers)


 # This class is part of an EXPERIMENTAL API.
class Query(object):
    """Query defines the gRPC querier service.
    """

    @staticmethod
    def Params(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/injective.oracle.v1beta1.Query/Params',
            injective_dot_oracle_dot_v1beta1_dot_query__pb2.QueryParamsRequest.SerializeToString,
            injective_dot_oracle_dot_v1beta1_dot_query__pb2.QueryParamsResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def BandRelayers(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/injective.oracle.v1beta1.Query/BandRelayers',
            injective_dot_oracle_dot_v1beta1_dot_query__pb2.QueryBandRelayersRequest.SerializeToString,
            injective_dot_oracle_dot_v1beta1_dot_query__pb2.QueryBandRelayersResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def BandPriceStates(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/injective.oracle.v1beta1.Query/BandPriceStates',
            injective_dot_oracle_dot_v1beta1_dot_query__pb2.QueryBandPriceStatesRequest.SerializeToString,
            injective_dot_oracle_dot_v1beta1_dot_query__pb2.QueryBandPriceStatesResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def BandIBCPriceStates(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/injective.oracle.v1beta1.Query/BandIBCPriceStates',
            injective_dot_oracle_dot_v1beta1_dot_query__pb2.QueryBandIBCPriceStatesRequest.SerializeToString,
            injective_dot_oracle_dot_v1beta1_dot_query__pb2.QueryBandIBCPriceStatesResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def PriceFeedPriceStates(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/injective.oracle.v1beta1.Query/PriceFeedPriceStates',
            injective_dot_oracle_dot_v1beta1_dot_query__pb2.QueryPriceFeedPriceStatesRequest.SerializeToString,
            injective_dot_oracle_dot_v1beta1_dot_query__pb2.QueryPriceFeedPriceStatesResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def CoinbasePriceStates(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/injective.oracle.v1beta1.Query/CoinbasePriceStates',
            injective_dot_oracle_dot_v1beta1_dot_query__pb2.QueryCoinbasePriceStatesRequest.SerializeToString,
            injective_dot_oracle_dot_v1beta1_dot_query__pb2.QueryCoinbasePriceStatesResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def PythPriceStates(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/injective.oracle.v1beta1.Query/PythPriceStates',
            injective_dot_oracle_dot_v1beta1_dot_query__pb2.QueryPythPriceStatesRequest.SerializeToString,
            injective_dot_oracle_dot_v1beta1_dot_query__pb2.QueryPythPriceStatesResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def StorkPriceStates(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/injective.oracle.v1beta1.Query/StorkPriceStates',
            injective_dot_oracle_dot_v1beta1_dot_query__pb2.QueryStorkPriceStatesRequest.SerializeToString,
            injective_dot_oracle_dot_v1beta1_dot_query__pb2.QueryStorkPriceStatesResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def StorkPublishers(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/injective.oracle.v1beta1.Query/StorkPublishers',
            injective_dot_oracle_dot_v1beta1_dot_query__pb2.QueryStorkPublishersRequest.SerializeToString,
            injective_dot_oracle_dot_v1beta1_dot_query__pb2.QueryStorkPublishersResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def ProviderPriceState(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/injective.oracle.v1beta1.Query/ProviderPriceState',
            injective_dot_oracle_dot_v1beta1_dot_query__pb2.QueryProviderPriceStateRequest.SerializeToString,
            injective_dot_oracle_dot_v1beta1_dot_query__pb2.QueryProviderPriceStateResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def OracleModuleState(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/injective.oracle.v1beta1.Query/OracleModuleState',
            injective_dot_oracle_dot_v1beta1_dot_query__pb2.QueryModuleStateRequest.SerializeToString,
            injective_dot_oracle_dot_v1beta1_dot_query__pb2.QueryModuleStateResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def HistoricalPriceRecords(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/injective.oracle.v1beta1.Query/HistoricalPriceRecords',
            injective_dot_oracle_dot_v1beta1_dot_query__pb2.QueryHistoricalPriceRecordsRequest.SerializeToString,
            injective_dot_oracle_dot_v1beta1_dot_query__pb2.QueryHistoricalPriceRecordsResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def OracleVolatility(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/injective.oracle.v1beta1.Query/OracleVolatility',
            injective_dot_oracle_dot_v1beta1_dot_query__pb2.QueryOracleVolatilityRequest.SerializeToString,
            injective_dot_oracle_dot_v1beta1_dot_query__pb2.QueryOracleVolatilityResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def OracleProvidersInfo(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/injective.oracle.v1beta1.Query/OracleProvidersInfo',
            injective_dot_oracle_dot_v1beta1_dot_query__pb2.QueryOracleProvidersInfoRequest.SerializeToString,
            injective_dot_oracle_dot_v1beta1_dot_query__pb2.QueryOracleProvidersInfoResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def OracleProviderPrices(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/injective.oracle.v1beta1.Query/OracleProviderPrices',
            injective_dot_oracle_dot_v1beta1_dot_query__pb2.QueryOracleProviderPricesRequest.SerializeToString,
            injective_dot_oracle_dot_v1beta1_dot_query__pb2.QueryOracleProviderPricesResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def OraclePrice(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/injective.oracle.v1beta1.Query/OraclePrice',
            injective_dot_oracle_dot_v1beta1_dot_query__pb2.QueryOraclePriceRequest.SerializeToString,
            injective_dot_oracle_dot_v1beta1_dot_query__pb2.QueryOraclePriceResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def PythPrice(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/injective.oracle.v1beta1.Query/PythPrice',
            injective_dot_oracle_dot_v1beta1_dot_query__pb2.QueryPythPriceRequest.SerializeToString,
            injective_dot_oracle_dot_v1beta1_dot_query__pb2.QueryPythPriceResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: cometbft/state/v1beta1/types.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from pyinjective.proto.gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from pyinjective.proto.cometbft.abci.v1beta1 import types_pb2 as cometbft_dot_abci_dot_v1beta1_dot_types__pb2
from pyinjective.proto.cometbft.types.v1beta1 import types_pb2 as cometbft_dot_types_dot_v1beta1_dot_types__pb2
from pyinjective.proto.cometbft.types.v1beta1 import validator_pb2 as cometbft_dot_types_dot_v1beta1_dot_validator__pb2
from pyinjective.proto.cometbft.types.v1beta1 import params_pb2 as cometbft_dot_types_dot_v1beta1_dot_params__pb2
from pyinjective.proto.cometbft.version.v1 import types_pb2 as cometbft_dot_version_dot_v1_dot_types__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\"cometbft/state/v1beta1/types.proto\x12\x16\x63ometbft.state.v1beta1\x1a\x14gogoproto/gogo.proto\x1a!cometbft/abci/v1beta1/types.proto\x1a\"cometbft/types/v1beta1/types.proto\x1a&cometbft/types/v1beta1/validator.proto\x1a#cometbft/types/v1beta1/params.proto\x1a\x1f\x63ometbft/version/v1/types.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"\xec\x01\n\rABCIResponses\x12I\n\x0b\x64\x65liver_txs\x18\x01 \x03(\x0b\x32(.cometbft.abci.v1beta1.ResponseDeliverTxR\ndeliverTxs\x12\x44\n\tend_block\x18\x02 \x01(\x0b\x32\'.cometbft.abci.v1beta1.ResponseEndBlockR\x08\x65ndBlock\x12J\n\x0b\x62\x65gin_block\x18\x03 \x01(\x0b\x32).cometbft.abci.v1beta1.ResponseBeginBlockR\nbeginBlock\"\x8b\x01\n\x0eValidatorsInfo\x12I\n\rvalidator_set\x18\x01 \x01(\x0b\x32$.cometbft.types.v1beta1.ValidatorSetR\x0cvalidatorSet\x12.\n\x13last_height_changed\x18\x02 \x01(\x03R\x11lastHeightChanged\"\x9f\x01\n\x13\x43onsensusParamsInfo\x12X\n\x10\x63onsensus_params\x18\x01 \x01(\x0b\x32\'.cometbft.types.v1beta1.ConsensusParamsB\x04\xc8\xde\x1f\x00R\x0f\x63onsensusParams\x12.\n\x13last_height_changed\x18\x02 \x01(\x03R\x11lastHeightChanged\"y\n\x11\x41\x42\x43IResponsesInfo\x12L\n\x0e\x61\x62\x63i_responses\x18\x01 \x01(\x0b\x32%.cometbft.state.v1beta1.ABCIResponsesR\rabciResponses\x12\x16\n\x06height\x18\x02 \x01(\x03R\x06height\"i\n\x07Version\x12\x42\n\tconsensus\x18\x01 \x01(\x0b\x32\x1e.cometbft.version.v1.ConsensusB\x04\xc8\xde\x1f\x00R\tconsensus\x12\x1a\n\x08software\x18\x02 \x01(\tR\x08software\"\x85\x07\n\x05State\x12?\n\x07version\x18\x01 \x01(\x0b\x32\x1f.cometbft.state.v1beta1.VersionB\x04\xc8\xde\x1f\x00R\x07version\x12&\n\x08\x63hain_id\x18\x02 \x01(\tB\x0b\xe2\xde\x1f\x07\x43hainIDR\x07\x63hainId\x12%\n\x0einitial_height\x18\x0e \x01(\x03R\rinitialHeight\x12*\n\x11last_block_height\x18\x03 \x01(\x03R\x0flastBlockHeight\x12X\n\rlast_block_id\x18\x04 \x01(\x0b\x32\x1f.cometbft.types.v1beta1.BlockIDB\x13\xc8\xde\x1f\x00\xe2\xde\x1f\x0bLastBlockIDR\x0blastBlockId\x12L\n\x0flast_block_time\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x08\xc8\xde\x1f\x00\x90\xdf\x1f\x01R\rlastBlockTime\x12M\n\x0fnext_validators\x18\x06 \x01(\x0b\x32$.cometbft.types.v1beta1.ValidatorSetR\x0enextValidators\x12\x44\n\nvalidators\x18\x07 \x01(\x0b\x32$.cometbft.types.v1beta1.ValidatorSetR\nvalidators\x12M\n\x0flast_validators\x18\x08 \x01(\x0b\x32$.cometbft.types.v1beta1.ValidatorSetR\x0elastValidators\x12\x43\n\x1elast_height_validators_changed\x18\t \x01(\x03R\x1blastHeightValidatorsChanged\x12X\n\x10\x63onsensus_params\x18\n \x01(\x0b\x32\'.cometbft.types.v1beta1.ConsensusParamsB\x04\xc8\xde\x1f\x00R\x0f\x63onsensusParams\x12N\n$last_height_consensus_params_changed\x18\x0b \x01(\x03R lastHeightConsensusParamsChanged\x12*\n\x11last_results_hash\x18\x0c \x01(\x0cR\x0flastResultsHash\x12\x19\n\x08\x61pp_hash\x18\r \x01(\x0cR\x07\x61ppHashB\xdb\x01\n\x1a\x63om.cometbft.state.v1beta1B\nTypesProtoP\x01Z7github.com/cometbft/cometbft/api/cometbft/state/v1beta1\xa2\x02\x03\x43SX\xaa\x02\x16\x43ometbft.State.V1beta1\xca\x02\x16\x43ometbft\\State\\V1beta1\xe2\x02\"Cometbft\\State\\V1beta1\\GPBMetadata\xea\x02\x18\x43ometbft::State::V1beta1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'cometbft.state.v1beta1.types_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\032com.cometbft.state.v1beta1B\nTypesProtoP\001Z7github.com/cometbft/cometbft/api/cometbft/state/v1beta1\242\002\003CSX\252\002\026Cometbft.State.V1beta1\312\002\026Cometbft\\State\\V1beta1\342\002\"Cometbft\\State\\V1beta1\\GPBMetadata\352\002\030Cometbft::State::V1beta1'
  _globals['_CONSENSUSPARAMSINFO'].fields_by_name['consensus_params']._loaded_options = None
  _globals['_CONSENSUSPARAMSINFO'].fields_by_name['consensus_params']._serialized_options = b'\310\336\037\000'
  _globals['_VERSION'].fields_by_name['consensus']._loaded_options = None
  _globals['_VERSION'].fields_by_name['consensus']._serialized_options = b'\310\336\037\000'
  _globals['_STATE'].fields_by_name['version']._loaded_options = None
  _globals['_STATE'].fields_by_name['version']._serialized_options = b'\310\336\037\000'
  _globals['_STATE'].fields_by_name['chain_id']._loaded_options = None
  _globals['_STATE'].fields_by_name['chain_id']._serialized_options = b'\342\336\037\007ChainID'
  _globals['_STATE'].fields_by_name['last_block_id']._loaded_options = None
  _globals['_STATE'].fields_by_name['last_block_id']._serialized_options = b'\310\336\037\000\342\336\037\013LastBlockID'
  _globals['_STATE'].fields_by_name['last_block_time']._loaded_options = None
  _globals['_STATE'].fields_by_name['last_block_time']._serialized_options = b'\310\336\037\000\220\337\037\001'
  _globals['_STATE'].fields_by_name['consensus_params']._loaded_options = None
  _globals['_STATE'].fields_by_name['consensus_params']._serialized_options = b'\310\336\037\000'
  _globals['_ABCIRESPONSES']._serialized_start=299
  _globals['_ABCIRESPONSES']._serialized_end=535
  _globals['_VALIDATORSINFO']._serialized_start=538
  _globals['_VALIDATORSINFO']._serialized_end=677
  _globals['_CONSENSUSPARAMSINFO']._serialized_start=680
  _globals['_CONSENSUSPARAMSINFO']._serialized_end=839
  _globals['_ABCIRESPONSESINFO']._serialized_start=841
  _globals['_ABCIRESPONSESINFO']._serialized_end=962
  _globals['_VERSION']._serialized_start=964
  _globals['_VERSION']._serialized_end=1069
  _globals['_STATE']._serialized_start=1072
  _globals['_STATE']._serialized_end=1973
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: cometbft/types/v1/params.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from pyinjective.proto.gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1e\x63ometbft/types/v1/params.proto\x12\x11\x63ometbft.types.v1\x1a\x14gogoproto/gogo.proto\x1a\x1egoogle/protobuf/duration.proto\x1a\x1egoogle/protobuf/wrappers.proto\"\xb9\x03\n\x0f\x43onsensusParams\x12\x34\n\x05\x62lock\x18\x01 \x01(\x0b\x32\x1e.cometbft.types.v1.BlockParamsR\x05\x62lock\x12=\n\x08\x65vidence\x18\x02 \x01(\x0b\x32!.cometbft.types.v1.EvidenceParamsR\x08\x65vidence\x12@\n\tvalidator\x18\x03 \x01(\x0b\x32\".cometbft.types.v1.ValidatorParamsR\tvalidator\x12:\n\x07version\x18\x04 \x01(\x0b\x32 .cometbft.types.v1.VersionParamsR\x07version\x12\x35\n\x04\x61\x62\x63i\x18\x05 \x01(\x0b\x32\x1d.cometbft.types.v1.ABCIParamsB\x02\x18\x01R\x04\x61\x62\x63i\x12@\n\tsynchrony\x18\x06 \x01(\x0b\x32\".cometbft.types.v1.SynchronyParamsR\tsynchrony\x12:\n\x07\x66\x65\x61ture\x18\x07 \x01(\x0b\x32 .cometbft.types.v1.FeatureParamsR\x07\x66\x65\x61ture\"I\n\x0b\x42lockParams\x12\x1b\n\tmax_bytes\x18\x01 \x01(\x03R\x08maxBytes\x12\x17\n\x07max_gas\x18\x02 \x01(\x03R\x06maxGasJ\x04\x08\x03\x10\x04\"\xa9\x01\n\x0e\x45videnceParams\x12+\n\x12max_age_num_blocks\x18\x01 \x01(\x03R\x0fmaxAgeNumBlocks\x12M\n\x10max_age_duration\x18\x02 \x01(\x0b\x32\x19.google.protobuf.DurationB\x08\xc8\xde\x1f\x00\x98\xdf\x1f\x01R\x0emaxAgeDuration\x12\x1b\n\tmax_bytes\x18\x03 \x01(\x03R\x08maxBytes\"?\n\x0fValidatorParams\x12\"\n\rpub_key_types\x18\x01 \x03(\tR\x0bpubKeyTypes:\x08\xb8\xa0\x1f\x01\xe8\xa0\x1f\x01\"+\n\rVersionParams\x12\x10\n\x03\x61pp\x18\x01 \x01(\x04R\x03\x61pp:\x08\xb8\xa0\x1f\x01\xe8\xa0\x1f\x01\"Z\n\x0cHashedParams\x12&\n\x0f\x62lock_max_bytes\x18\x01 \x01(\x03R\rblockMaxBytes\x12\"\n\rblock_max_gas\x18\x02 \x01(\x03R\x0b\x62lockMaxGas\"\x96\x01\n\x0fSynchronyParams\x12=\n\tprecision\x18\x01 \x01(\x0b\x32\x19.google.protobuf.DurationB\x04\x98\xdf\x1f\x01R\tprecision\x12\x44\n\rmessage_delay\x18\x02 \x01(\x0b\x32\x19.google.protobuf.DurationB\x04\x98\xdf\x1f\x01R\x0cmessageDelay\"\xc6\x01\n\rFeatureParams\x12\x64\n\x1dvote_extensions_enable_height\x18\x01 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x04\xc8\xde\x1f\x01R\x1avoteExtensionsEnableHeight\x12O\n\x12pbts_enable_height\x18\x02 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x04\xc8\xde\x1f\x01R\x10pbtsEnableHeight\"S\n\nABCIParams\x12\x41\n\x1dvote_extensions_enable_height\x18\x01 \x01(\x03R\x1avoteExtensionsEnableHeight:\x02\x18\x01\x42\xc2\x01\n\x15\x63om.cometbft.types.v1B\x0bParamsProtoP\x01Z2github.com/cometbft/cometbft/api/cometbft/types/v1\xa2\x02\x03\x43TX\xaa\x02\x11\x43ometbft.Types.V1\xca\x02\x11\x43ometbft\\Types\\V1\xe2\x02\x1d\x43ometbft\\Types\\V1\\GPBMetadata\xea\x02\x13\x43ometbft::Types::V1\xa8\xe2\x1e\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'cometbft.types.v1.params_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\025com.cometbft.types.v1B\013ParamsProtoP\001Z2github.com/cometbft/cometbft/api/cometbft/types/v1\242\002\003CTX\252\002\021Cometbft.Types.V1\312\002\021Cometbft\\Types\\V1\342\002\035Cometbft\\Types\\V1\\GPBMetadata\352\002\023Cometbft::Types::V1\250\342\036\001'
  _globals['_CONSENSUSPARAMS'].fields_by_name['abci']._loaded_options = None
  _globals['_CONSENSUSPARAMS'].fields_by_name['abci']._serialized_options = b'\030\001'
  _globals['_EVIDENCEPARAMS'].fields_by_name['max_age_duration']._loaded_options = None
  _globals['_EVIDENCEPARAMS'].fields_by_name['max_age_duration']._serialized_options = b'\310\336\037\000\230\337\037\001'
  _globals['_VALIDATORPARAMS']._loaded_options = None
  _globals['_VALIDATORPARAMS']._serialized_options = b'\270\240\037\001\350\240\037\001'
  _globals['_VERSIONPARAMS']._loaded_options = None
  _globals['_VERSIONPARAMS']._serialized_options = b'\270\240\037\001\350\240\037\001'
  _globals['_SYNCHRONYPARAMS'].fields_by_name['precision']._loaded_options = None
  _globals['_SYNCHRONYPARAMS'].fields_by_name['precision']._serialized_options = b'\230\337\037\001'
  _globals['_SYNCHRONYPARAMS'].fields_by_name['message_delay']._loaded_options = None
  _globals['_SYNCHRONYPARAMS'].fields_by_name['message_delay']._serialized_options = b'\230\337\037\001'
  _globals['_FEATUREPARAMS'].fields_by_name['vote_extensions_enable_height']._loaded_options = None
  _globals['_FEATUREPARAMS'].fields_by_name['vote_extensions_enable_height']._serialized_options = b'\310\336\037\001'
  _globals['_FEATUREPARAMS'].fields_by_name['pbts_enable_height']._loaded_options = None
  _globals['_FEATUREPARAMS'].fields_by_name['pbts_enable_height']._serialized_options = b'\310\336\037\001'
  _globals['_ABCIPARAMS']._loaded_options = None
  _globals['_ABCIPARAMS']._serialized_options = b'\030\001'
  _globals['_CONSENSUSPARAMS']._serialized_start=140
  _globals['_CONSENSUSPARAMS']._serialized_end=581
  _globals['_BLOCKPARAMS']._serialized_start=583
  _globals['_BLOCKPARAMS']._serialized_end=656
  _globals['_EVIDENCEPARAMS']._serialized_start=659
  _globals['_EVIDENCEPARAMS']._serialized_end=828
  _globals['_VALIDATORPARAMS']._serialized_start=830
  _globals['_VALIDATORPARAMS']._serialized_end=893
  _globals['_VERSIONPARAMS']._serialized_start=895
  _globals['_VERSIONPARAMS']._serialized_end=938
  _globals['_HASHEDPARAMS']._serialized_start=940
  _globals['_HASHEDPARAMS']._serialized_end=1030
  _globals['_SYNCHRONYPARAMS']._serialized_start=1033
  _globals['_SYNCHRONYPARAMS']._serialized_end=1183
  _globals['_FEATUREPARAMS']._serialized_start=1186
  _globals['_FEATUREPARAMS']._serialized_end=1384
  _globals['_ABCIPARAMS']._serialized_start=1386
  _globals['_ABCIPARAMS']._serialized_end=1469
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: injective/exchange/v1beta1/authz.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from pyinjective.proto.cosmos_proto import cosmos_pb2 as cosmos__proto_dot_cosmos__pb2
from pyinjective.proto.amino import amino_pb2 as amino_dot_amino__pb2
from pyinjective.proto.cosmos.base.v1beta1 import coin_pb2 as cosmos_dot_base_dot_v1beta1_dot_coin__pb2
from pyinjective.proto.gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n&injective/exchange/v1beta1/authz.proto\x12\x1ainjective.exchange.v1beta1\x1a\x19\x63osmos_proto/cosmos.proto\x1a\x11\x61mino/amino.proto\x1a\x1e\x63osmos/base/v1beta1/coin.proto\x1a\x14gogoproto/gogo.proto\"\x99\x01\n\x19\x43reateSpotLimitOrderAuthz\x12#\n\rsubaccount_id\x18\x01 \x01(\tR\x0csubaccountId\x12\x1d\n\nmarket_ids\x18\x02 \x03(\tR\tmarketIds:8\xca\xb4-\rAuthorization\x8a\xe7\xb0*\"exchange/CreateSpotLimitOrderAuthz\"\x9b\x01\n\x1a\x43reateSpotMarketOrderAuthz\x12#\n\rsubaccount_id\x18\x01 \x01(\tR\x0csubaccountId\x12\x1d\n\nmarket_ids\x18\x02 \x03(\tR\tmarketIds:9\xca\xb4-\rAuthorization\x8a\xe7\xb0*#exchange/CreateSpotMarketOrderAuthz\"\xa5\x01\n\x1f\x42\x61tchCreateSpotLimitOrdersAuthz\x12#\n\rsubaccount_id\x18\x01 \x01(\tR\x0csubaccountId\x12\x1d\n\nmarket_ids\x18\x02 \x03(\tR\tmarketIds:>\xca\xb4-\rAuthorization\x8a\xe7\xb0*(exchange/BatchCreateSpotLimitOrdersAuthz\"\x8f\x01\n\x14\x43\x61ncelSpotOrderAuthz\x12#\n\rsubaccount_id\x18\x01 \x01(\tR\x0csubaccountId\x12\x1d\n\nmarket_ids\x18\x02 \x03(\tR\tmarketIds:3\xca\xb4-\rAuthorization\x8a\xe7\xb0*\x1d\x65xchange/CancelSpotOrderAuthz\"\x9b\x01\n\x1a\x42\x61tchCancelSpotOrdersAuthz\x12#\n\rsubaccount_id\x18\x01 \x01(\tR\x0csubaccountId\x12\x1d\n\nmarket_ids\x18\x02 \x03(\tR\tmarketIds:9\xca\xb4-\rAuthorization\x8a\xe7\xb0*#exchange/BatchCancelSpotOrdersAuthz\"\xa5\x01\n\x1f\x43reateDerivativeLimitOrderAuthz\x12#\n\rsubaccount_id\x18\x01 \x01(\tR\x0csubaccountId\x12\x1d\n\nmarket_ids\x18\x02 \x03(\tR\tmarketIds:>\xca\xb4-\rAuthorization\x8a\xe7\xb0*(exchange/CreateDerivativeLimitOrderAuthz\"\xa7\x01\n CreateDerivativeMarketOrderAuthz\x12#\n\rsubaccount_id\x18\x01 \x01(\tR\x0csubaccountId\x12\x1d\n\nmarket_ids\x18\x02 \x03(\tR\tmarketIds:?\xca\xb4-\rAuthorization\x8a\xe7\xb0*)exchange/CreateDerivativeMarketOrderAuthz\"\xb1\x01\n%BatchCreateDerivativeLimitOrdersAuthz\x12#\n\rsubaccount_id\x18\x01 \x01(\tR\x0csubaccountId\x12\x1d\n\nmarket_ids\x18\x02 \x03(\tR\tmarketIds:D\xca\xb4-\rAuthorization\x8a\xe7\xb0*.exchange/BatchCreateDerivativeLimitOrdersAuthz\"\x9b\x01\n\x1a\x43\x61ncelDerivativeOrderAuthz\x12#\n\rsubaccount_id\x18\x01 \x01(\tR\x0csubaccountId\x12\x1d\n\nmarket_ids\x18\x02 \x03(\tR\tmarketIds:9\xca\xb4-\rAuthorization\x8a\xe7\xb0*#exchange/CancelDerivativeOrderAuthz\"\xa7\x01\n BatchCancelDerivativeOrdersAuthz\x12#\n\rsubaccount_id\x18\x01 \x01(\tR\x0csubaccountId\x12\x1d\n\nmarket_ids\x18\x02 \x03(\tR\tmarketIds:?\xca\xb4-\rAuthorization\x8a\xe7\xb0*)exchange/BatchCancelDerivativeOrdersAuthz\"\xc6\x01\n\x16\x42\x61tchUpdateOrdersAuthz\x12#\n\rsubaccount_id\x18\x01 \x01(\tR\x0csubaccountId\x12!\n\x0cspot_markets\x18\x02 \x03(\tR\x0bspotMarkets\x12-\n\x12\x64\x65rivative_markets\x18\x03 \x03(\tR\x11\x64\x65rivativeMarkets:5\xca\xb4-\rAuthorization\x8a\xe7\xb0*\x1f\x65xchange/BatchUpdateOrdersAuthz\"\x89\x02\n\x1cGenericExchangeAuthorization\x12\x10\n\x03msg\x18\x01 \x01(\tR\x03msg\x12\x82\x01\n\x0bspend_limit\x18\x02 \x03(\x0b\x32\x19.cosmos.base.v1beta1.CoinBF\xc8\xde\x1f\x00\xaa\xdf\x1f(github.com/cosmos/cosmos-sdk/types.Coins\x9a\xe7\xb0*\x0clegacy_coins\xa8\xe7\xb0*\x01R\nspendLimit:R\xca\xb4-\"cosmos.authz.v1beta1.Authorization\x8a\xe7\xb0*\'cosmos-sdk/GenericExchangeAuthorizationB\x86\x02\n\x1e\x63om.injective.exchange.v1beta1B\nAuthzProtoP\x01ZNgithub.com/InjectiveLabs/injective-core/injective-chain/modules/exchange/types\xa2\x02\x03IEX\xaa\x02\x1aInjective.Exchange.V1beta1\xca\x02\x1aInjective\\Exchange\\V1beta1\xe2\x02&Injective\\Exchange\\V1beta1\\GPBMetadata\xea\x02\x1cInjective::Exchange::V1beta1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'injective.exchange.v1beta1.authz_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\036com.injective.exchange.v1beta1B\nAuthzProtoP\001ZNgithub.com/InjectiveLabs/injective-core/injective-chain/modules/exchange/types\242\002\003IEX\252\002\032Injective.Exchange.V1beta1\312\002\032Injective\\Exchange\\V1beta1\342\002&Injective\\Exchange\\V1beta1\\GPBMetadata\352\002\034Injective::Exchange::V1beta1'
  _globals['_CREATESPOTLIMITORDERAUTHZ']._loaded_options = None
  _globals['_CREATESPOTLIMITORDERAUTHZ']._serialized_options = b'\312\264-\rAuthorization\212\347\260*\"exchange/CreateSpotLimitOrderAuthz'
  _globals['_CREATESPOTMARKETORDERAUTHZ']._loaded_options = None
  _globals['_CREATESPOTMARKETORDERAUTHZ']._serialized_options = b'\312\264-\rAuthorization\212\347\260*#exchange/CreateSpotMarketOrderAuthz'
  _globals['_BATCHCREATESPOTLIMITORDERSAUTHZ']._loaded_options = None
  _globals['_BATCHCREATESPOTLIMITORDERSAUTHZ']._serialized_options = b'\312\264-\rAuthorization\212\347\260*(exchange/BatchCreateSpotLimitOrdersAuthz'
  _globals['_CANCELSPOTORDERAUTHZ']._loaded_options = None
  _globals['_CANCELSPOTORDERAUTHZ']._serialized_options = b'\312\264-\rAuthorization\212\347\260*\035exchange/CancelSpotOrderAuthz'
  _globals['_BATCHCANCELSPOTORDERSAUTHZ']._loaded_options = None
  _globals['_BATCHCANCELSPOTORDERSAUTHZ']._serialized_options = b'\312\264-\rAuthorization\212\347\260*#exchange/BatchCancelSpotOrdersAuthz'
  _globals['_CREATEDERIVATIVELIMITORDERAUTHZ']._loaded_options = None
  _globals['_CREATEDERIVATIVELIMITORDERAUTHZ']._serialized_options = b'\312\264-\rAuthorization\212\347\260*(exchange/CreateDerivativeLimitOrderAuthz'
  _globals['_CREATEDERIVATIVEMARKETORDERAUTHZ']._loaded_options = None
  _globals['_CREATEDERIVATIVEMARKETORDERAUTHZ']._serialized_options = b'\312\264-\rAuthorization\212\347\260*)exchange/CreateDerivativeMarketOrderAuthz'
  _globals['_BATCHCREATEDERIVATIVELIMITORDERSAUTHZ']._loaded_options = None
  _globals['_BATCHCREATEDERIVATIVELIMITORDERSAUTHZ']._serialized_options = b'\312\264-\rAuthorization\212\347\260*.exchange/BatchCreateDerivativeLimitOrdersAuthz'
  _globals['_CANCELDERIVATIVEORDERAUTHZ']._loaded_options = None
  _globals['_CANCELDERIVATIVEORDERAUTHZ']._serialized_options = b'\312\264-\rAuthorization\212\347\260*#exchange/CancelDerivativeOrderAuthz'
  _globals['_BATCHCANCELDERIVATIVEORDERSAUTHZ']._loaded_options = None
  _globals['_BATCHCANCELDERIVATIVEORDERSAUTHZ']._serialized_options = b'\312\264-\rAuthorization\212\347\260*)exchange/BatchCancelDerivativeOrdersAuthz'
  _globals['_BATCHUPDATEORDERSAUTHZ']._loaded_options = None
  _globals['_BATCHUPDATEORDERSAUTHZ']._serialized_options = b'\312\264-\rAuthorization\212\347\260*\037exchange/BatchUpdateOrdersAuthz'
  _globals['_GENERICEXCHANGEAUTHORIZATION'].fields_by_name['spend_limit']._loaded_options = None
  _globals['_GENERICEXCHANGEAUTHORIZATION'].fields_by_name['spend_limit']._serialized_options = b'\310\336\037\000\252\337\037(github.com/cosmos/cosmos-sdk/types.Coins\232\347\260*\014legacy_coins\250\347\260*\001'
  _globals['_GENERICEXCHANGEAUTHORIZATION']._loaded_options = None
  _globals['_GENERICEXCHANGEAUTHORIZATION']._serialized_options = b'\312\264-\"cosmos.authz.v1beta1.Authorization\212\347\260*\'cosmos-sdk/GenericExchangeAuthorization'
  _globals['_CREATESPOTLIMITORDERAUTHZ']._serialized_start=171
  _globals['_CREATESPOTLIMITORDERAUTHZ']._serialized_end=324
  _globals['_CREATESPOTMARKETORDERAUTHZ']._serialized_start=327
  _globals['_CREATESPOTMARKETORDERAUTHZ']._serialized_end=482
  _globals['_BATCHCREATESPOTLIMITORDERSAUTHZ']._serialized_start=485
  _globals['_BATCHCREATESPOTLIMITORDERSAUTHZ']._serialized_end=650
  _globals['_CANCELSPOTORDERAUTHZ']._serialized_start=653
  _globals['_CANCELSPOTORDERAUTHZ']._serialized_end=796
  _globals['_BATCHCANCELSPOTORDERSAUTHZ']._serialized_start=799
  _globals['_BATCHCANCELSPOTORDERSAUTHZ']._serialized_end=954
  _globals['_CREATEDERIVATIVELIMITORDERAUTHZ']._serialized_start=957
  _globals['_CREATEDERIVATIVELIMITORDERAUTHZ']._serialized_end=1122
  _globals['_CREATEDERIVATIVEMARKETORDERAUTHZ']._serialized_start=1125
  _globals['_CREATEDERIVATIVEMARKETORDERAUTHZ']._serialized_end=1292
  _globals['_BATCHCREATEDERIVATIVELIMITORDERSAUTHZ']._serialized_start=1295
  _globals['_BATCHCREATEDERIVATIVELIMITORDERSAUTHZ']._serialized_end=1472
  _globals['_CANCELDERIVATIVEORDERAUTHZ']._serialized_start=1475
  _globals['_CANCELDERIVATIVEORDERAUTHZ']._serialized_end=1630
  _globals['_BATCHCANCELDERIVATIVEORDERSAUTHZ']._serialized_start=1633
  _globals['_BATCHCANCELDERIVATIVEORDERSAUTHZ']._serialized_end=1800
  _globals['_BATCHUPDATEORDERSAUTHZ']._serialized_start=1803
  _globals['_BATCHUPDATEORDERSAUTHZ']._serialized_end=2001
  _globals['_GENERICEXCHANGEAUTHORIZATION']._serialized_start=2004
  _globals['_GENERICEXCHANGEAUTHORIZATION']._serialized_end=2269
# @@protoc_insertion_point(module_scope)



from typing import Any, Callable, Dict, Optional

from grpc import Channel

from pyinjective.client.model.pagination import PaginationOption
from pyinjective.core.network import CookieAssistant
from pyinjective.proto.ibc.core.connection.v1 import (
    query_pb2 as ibc_connection_query,
    query_pb2_grpc as ibc_connection_query_grpc,
)
from pyinjective.utils.grpc_api_request_assistant import GrpcApiRequestAssistant


class IBCConnectionGrpcApi:
    def __init__(self, channel: Channel, cookie_assistant: CookieAssistant):
        self._stub = ibc_connection_query_grpc.QueryStub(channel)
        self._assistant = GrpcApiRequestAssistant(cookie_assistant=cookie_assistant)

    async def fetch_connection(self, connection_id: str) -> Dict[str, Any]:
        request = ibc_connection_query.QueryConnectionRequest(connection_id=connection_id)
        response = await self._execute_call(call=self._stub.Connection, request=request)

        return response

    async def fetch_connections(self, pagination: Optional[PaginationOption] = None) -> Dict[str, Any]:
        if pagination is None:
            pagination = PaginationOption()
        request = ibc_connection_query.QueryConnectionsRequest(pagination=pagination.create_pagination_request())
        response = await self._execute_call(call=self._stub.Connections, request=request)

        return response

    async def fetch_client_connections(self, client_id: str) -> Dict[str, Any]:
        request = ibc_connection_query.QueryClientConnectionsRequest(client_id=client_id)
        response = await self._execute_call(call=self._stub.ClientConnections, request=request)

        return response

    async def fetch_connection_client_state(self, connection_id: str) -> Dict[str, Any]:
        request = ibc_connection_query.QueryConnectionClientStateRequest(connection_id=connection_id)
        response = await self._execute_call(call=self._stub.ConnectionClientState, request=request)

        return response

    async def fetch_connection_consensus_state(
        self,
        connection_id: str,
        revision_number: int,
        revision_height: int,
    ) -> Dict[str, Any]:
        request = ibc_connection_query.QueryConnectionConsensusStateRequest(
            connection_id=connection_id,
            revision_number=revision_number,
            revision_height=revision_height,
        )
        response = await self._execute_call(call=self._stub.ConnectionConsensusState, request=request)

        return response

    async def fetch_connection_params(self) -> Dict[str, Any]:
        request = ibc_connection_query.QueryConnectionParamsRequest()
        response = await self._execute_call(call=self._stub.ConnectionParams, request=request)

        return response

    async def _execute_call(self, call: Callable, request) -> Dict[str, Any]:
        return await self._assistant.execute_call(call=call, request=request)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: cosmos/bank/module/v1/module.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from pyinjective.proto.cosmos.app.v1alpha1 import module_pb2 as cosmos_dot_app_dot_v1alpha1_dot_module__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\"cosmos/bank/module/v1/module.proto\x12\x15\x63osmos.bank.module.v1\x1a cosmos/app/v1alpha1/module.proto\"\xcb\x01\n\x06Module\x12G\n blocked_module_accounts_override\x18\x01 \x03(\tR\x1d\x62lockedModuleAccountsOverride\x12\x1c\n\tauthority\x18\x02 \x01(\tR\tauthority\x12-\n\x12restrictions_order\x18\x03 \x03(\tR\x11restrictionsOrder:+\xba\xc0\x96\xda\x01%\n#github.com/cosmos/cosmos-sdk/x/bankB\x9f\x01\n\x19\x63om.cosmos.bank.module.v1B\x0bModuleProtoP\x01\xa2\x02\x03\x43\x42M\xaa\x02\x15\x43osmos.Bank.Module.V1\xca\x02\x15\x43osmos\\Bank\\Module\\V1\xe2\x02!Cosmos\\Bank\\Module\\V1\\GPBMetadata\xea\x02\x18\x43osmos::Bank::Module::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'cosmos.bank.module.v1.module_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\031com.cosmos.bank.module.v1B\013ModuleProtoP\001\242\002\003CBM\252\002\025Cosmos.Bank.Module.V1\312\002\025Cosmos\\Bank\\Module\\V1\342\002!Cosmos\\Bank\\Module\\V1\\GPBMetadata\352\002\030Cosmos::Bank::Module::V1'
  _globals['_MODULE']._loaded_options = None
  _globals['_MODULE']._serialized_options = b'\272\300\226\332\001%\n#github.com/cosmos/cosmos-sdk/x/bank'
  _globals['_MODULE']._serialized_start=96
  _globals['_MODULE']._serialized_end=299
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: cosmos/autocli/v1/options.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1f\x63osmos/autocli/v1/options.proto\x12\x11\x63osmos.autocli.v1\"\x8f\x01\n\rModuleOptions\x12;\n\x02tx\x18\x01 \x01(\x0b\x32+.cosmos.autocli.v1.ServiceCommandDescriptorR\x02tx\x12\x41\n\x05query\x18\x02 \x01(\x0b\x32+.cosmos.autocli.v1.ServiceCommandDescriptorR\x05query\"\xa4\x03\n\x18ServiceCommandDescriptor\x12\x18\n\x07service\x18\x01 \x01(\tR\x07service\x12T\n\x13rpc_command_options\x18\x02 \x03(\x0b\x32$.cosmos.autocli.v1.RpcCommandOptionsR\x11rpcCommandOptions\x12_\n\x0csub_commands\x18\x03 \x03(\x0b\x32<.cosmos.autocli.v1.ServiceCommandDescriptor.SubCommandsEntryR\x0bsubCommands\x12\x34\n\x16\x65nhance_custom_command\x18\x04 \x01(\x08R\x14\x65nhanceCustomCommand\x12\x14\n\x05short\x18\x05 \x01(\tR\x05short\x1ak\n\x10SubCommandsEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x41\n\x05value\x18\x02 \x01(\x0b\x32+.cosmos.autocli.v1.ServiceCommandDescriptorR\x05value:\x02\x38\x01\"\x9c\x04\n\x11RpcCommandOptions\x12\x1d\n\nrpc_method\x18\x01 \x01(\tR\trpcMethod\x12\x10\n\x03use\x18\x02 \x01(\tR\x03use\x12\x12\n\x04long\x18\x03 \x01(\tR\x04long\x12\x14\n\x05short\x18\x04 \x01(\tR\x05short\x12\x18\n\x07\x65xample\x18\x05 \x01(\tR\x07\x65xample\x12\x14\n\x05\x61lias\x18\x06 \x03(\tR\x05\x61lias\x12\x1f\n\x0bsuggest_for\x18\x07 \x03(\tR\nsuggestFor\x12\x1e\n\ndeprecated\x18\x08 \x01(\tR\ndeprecated\x12\x18\n\x07version\x18\t \x01(\tR\x07version\x12X\n\x0c\x66lag_options\x18\n \x03(\x0b\x32\x35.cosmos.autocli.v1.RpcCommandOptions.FlagOptionsEntryR\x0b\x66lagOptions\x12S\n\x0fpositional_args\x18\x0b \x03(\x0b\x32*.cosmos.autocli.v1.PositionalArgDescriptorR\x0epositionalArgs\x12\x12\n\x04skip\x18\x0c \x01(\x08R\x04skip\x1a^\n\x10\x46lagOptionsEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x34\n\x05value\x18\x02 \x01(\x0b\x32\x1e.cosmos.autocli.v1.FlagOptionsR\x05value:\x02\x38\x01\"\xe5\x01\n\x0b\x46lagOptions\x12\x12\n\x04name\x18\x01 \x01(\tR\x04name\x12\x1c\n\tshorthand\x18\x02 \x01(\tR\tshorthand\x12\x14\n\x05usage\x18\x03 \x01(\tR\x05usage\x12#\n\rdefault_value\x18\x04 \x01(\tR\x0c\x64\x65\x66\x61ultValue\x12\x1e\n\ndeprecated\x18\x06 \x01(\tR\ndeprecated\x12\x31\n\x14shorthand_deprecated\x18\x07 \x01(\tR\x13shorthandDeprecated\x12\x16\n\x06hidden\x18\x08 \x01(\x08R\x06hidden\"p\n\x17PositionalArgDescriptor\x12\x1f\n\x0bproto_field\x18\x01 \x01(\tR\nprotoField\x12\x18\n\x07varargs\x18\x02 \x01(\x08R\x07varargs\x12\x1a\n\x08optional\x18\x03 \x01(\x08R\x08optionalB\xb6\x01\n\x15\x63om.cosmos.autocli.v1B\x0cOptionsProtoP\x01Z)cosmossdk.io/api/cosmos/base/cli/v1;cliv1\xa2\x02\x03\x43\x41X\xaa\x02\x11\x43osmos.Autocli.V1\xca\x02\x11\x43osmos\\Autocli\\V1\xe2\x02\x1d\x43osmos\\Autocli\\V1\\GPBMetadata\xea\x02\x13\x43osmos::Autocli::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'cosmos.autocli.v1.options_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\025com.cosmos.autocli.v1B\014OptionsProtoP\001Z)cosmossdk.io/api/cosmos/base/cli/v1;cliv1\242\002\003CAX\252\002\021Cosmos.Autocli.V1\312\002\021Cosmos\\Autocli\\V1\342\002\035Cosmos\\Autocli\\V1\\GPBMetadata\352\002\023Cosmos::Autocli::V1'
  _globals['_SERVICECOMMANDDESCRIPTOR_SUBCOMMANDSENTRY']._loaded_options = None
  _globals['_SERVICECOMMANDDESCRIPTOR_SUBCOMMANDSENTRY']._serialized_options = b'8\001'
  _globals['_RPCCOMMANDOPTIONS_FLAGOPTIONSENTRY']._loaded_options = None
  _globals['_RPCCOMMANDOPTIONS_FLAGOPTIONSENTRY']._serialized_options = b'8\001'
  _globals['_MODULEOPTIONS']._serialized_start=55
  _globals['_MODULEOPTIONS']._serialized_end=198
  _globals['_SERVICECOMMANDDESCRIPTOR']._serialized_start=201
  _globals['_SERVICECOMMANDDESCRIPTOR']._serialized_end=621
  _globals['_SERVICECOMMANDDESCRIPTOR_SUBCOMMANDSENTRY']._serialized_start=514
  _globals['_SERVICECOMMANDDESCRIPTOR_SUBCOMMANDSENTRY']._serialized_end=621
  _globals['_RPCCOMMANDOPTIONS']._serialized_start=624
  _globals['_RPCCOMMANDOPTIONS']._serialized_end=1164
  _globals['_RPCCOMMANDOPTIONS_FLAGOPTIONSENTRY']._serialized_start=1070
  _globals['_RPCCOMMANDOPTIONS_FLAGOPTIONSENTRY']._serialized_end=1164
  _globals['_FLAGOPTIONS']._serialized_start=1167
  _globals['_FLAGOPTIONS']._serialized_end=1396
  _globals['_POSITIONALARGDESCRIPTOR']._serialized_start=1398
  _globals['_POSITIONALARGDESCRIPTOR']._serialized_end=1510
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from pyinjective.proto.ibc.lightclients.wasm.v1 import tx_pb2 as ibc_dot_lightclients_dot_wasm_dot_v1_dot_tx__pb2


class MsgStub(object):
    """Msg defines the ibc/08-wasm Msg service.
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.StoreCode = channel.unary_unary(
                '/ibc.lightclients.wasm.v1.Msg/StoreCode',
                request_serializer=ibc_dot_lightclients_dot_wasm_dot_v1_dot_tx__pb2.MsgStoreCode.SerializeToString,
                response_deserializer=ibc_dot_lightclients_dot_wasm_dot_v1_dot_tx__pb2.MsgStoreCodeResponse.FromString,
                _registered_method=True)
        self.RemoveChecksum = channel.unary_unary(
                '/ibc.lightclients.wasm.v1.Msg/RemoveChecksum',
                request_serializer=ibc_dot_lightclients_dot_wasm_dot_v1_dot_tx__pb2.MsgRemoveChecksum.SerializeToString,
                response_deserializer=ibc_dot_lightclients_dot_wasm_dot_v1_dot_tx__pb2.MsgRemoveChecksumResponse.FromString,
                _registered_method=True)
        self.MigrateContract = channel.unary_unary(
                '/ibc.lightclients.wasm.v1.Msg/MigrateContract',
                request_serializer=ibc_dot_lightclients_dot_wasm_dot_v1_dot_tx__pb2.MsgMigrateContract.SerializeToString,
                response_deserializer=ibc_dot_lightclients_dot_wasm_dot_v1_dot_tx__pb2.MsgMigrateContractResponse.FromString,
                _registered_method=True)


class MsgServicer(object):
    """Msg defines the ibc/08-wasm Msg service.
    """

    def StoreCode(self, request, context):
        """StoreCode defines a rpc handler method for MsgStoreCode.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def RemoveChecksum(self, request, context):
        """RemoveChecksum defines a rpc handler method for MsgRemoveChecksum.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def MigrateContract(self, request, context):
        """MigrateContract defines a rpc handler method for MsgMigrateContract.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_MsgServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'StoreCode': grpc.unary_unary_rpc_method_handler(
                    servicer.StoreCode,
                    request_deserializer=ibc_dot_lightclients_dot_wasm_dot_v1_dot_tx__pb2.MsgStoreCode.FromString,
                    response_serializer=ibc_dot_lightclients_dot_wasm_dot_v1_dot_tx__pb2.MsgStoreCodeResponse.SerializeToString,
            ),
            'RemoveChecksum': grpc.unary_unary_rpc_method_handler(
                    servicer.RemoveChecksum,
                    request_deserializer=ibc_dot_lightclients_dot_wasm_dot_v1_dot_tx__pb2.MsgRemoveChecksum.FromString,
                    response_serializer=ibc_dot_lightclients_dot_wasm_dot_v1_dot_tx__pb2.MsgRemoveChecksumResponse.SerializeToString,
            ),
            'MigrateContract': grpc.unary_unary_rpc_method_handler(
                    servicer.MigrateContract,
                    request_deserializer=ibc_dot_lightclients_dot_wasm_dot_v1_dot_tx__pb2.MsgMigrateContract.FromString,
                    response_serializer=ibc_dot_lightclients_dot_wasm_dot_v1_dot_tx__pb2.MsgMigrateContractResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'ibc.lightclients.wasm.v1.Msg', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))
    server.add_registered_method_handlers('ibc.lightclients.wasm.v1.Msg', rpc_method_handlers)


 # This class is part of an EXPERIMENTAL API.
class Msg(object):
    """Msg defines the ibc/08-wasm Msg service.
    """

    @staticmethod
    def StoreCode(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/ibc.lightclients.wasm.v1.Msg/StoreCode',
            ibc_dot_lightclients_dot_wasm_dot_v1_dot_tx__pb2.MsgStoreCode.SerializeToString,
            ibc_dot_lightclients_dot_wasm_dot_v1_dot_tx__pb2.MsgStoreCodeResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def RemoveChecksum(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/ibc.lightclients.wasm.v1.Msg/RemoveChecksum',
            ibc_dot_lightclients_dot_wasm_dot_v1_dot_tx__pb2.MsgRemoveChecksum.SerializeToString,
            ibc_dot_lightclients_dot_wasm_dot_v1_dot_tx__pb2.MsgRemoveChecksumResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def MigrateContract(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/ibc.lightclients.wasm.v1.Msg/MigrateContract',
            ibc_dot_lightclients_dot_wasm_dot_v1_dot_tx__pb2.MsgMigrateContract.SerializeToString,
            ibc_dot_lightclients_dot_wasm_dot_v1_dot_tx__pb2.MsgMigrateContractResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: cosmos/app/v1alpha1/config.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n cosmos/app/v1alpha1/config.proto\x12\x13\x63osmos.app.v1alpha1\x1a\x19google/protobuf/any.proto\"\x92\x01\n\x06\x43onfig\x12;\n\x07modules\x18\x01 \x03(\x0b\x32!.cosmos.app.v1alpha1.ModuleConfigR\x07modules\x12K\n\x0fgolang_bindings\x18\x02 \x03(\x0b\x32\".cosmos.app.v1alpha1.GolangBindingR\x0egolangBindings\"\x9d\x01\n\x0cModuleConfig\x12\x12\n\x04name\x18\x01 \x01(\tR\x04name\x12,\n\x06\x63onfig\x18\x02 \x01(\x0b\x32\x14.google.protobuf.AnyR\x06\x63onfig\x12K\n\x0fgolang_bindings\x18\x03 \x03(\x0b\x32\".cosmos.app.v1alpha1.GolangBindingR\x0egolangBindings\"^\n\rGolangBinding\x12%\n\x0einterface_type\x18\x01 \x01(\tR\rinterfaceType\x12&\n\x0eimplementation\x18\x02 \x01(\tR\x0eimplementationB\x94\x01\n\x17\x63om.cosmos.app.v1alpha1B\x0b\x43onfigProtoP\x01\xa2\x02\x03\x43\x41X\xaa\x02\x13\x43osmos.App.V1alpha1\xca\x02\x13\x43osmos\\App\\V1alpha1\xe2\x02\x1f\x43osmos\\App\\V1alpha1\\GPBMetadata\xea\x02\x15\x43osmos::App::V1alpha1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'cosmos.app.v1alpha1.config_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\027com.cosmos.app.v1alpha1B\013ConfigProtoP\001\242\002\003CAX\252\002\023Cosmos.App.V1alpha1\312\002\023Cosmos\\App\\V1alpha1\342\002\037Cosmos\\App\\V1alpha1\\GPBMetadata\352\002\025Cosmos::App::V1alpha1'
  _globals['_CONFIG']._serialized_start=85
  _globals['_CONFIG']._serialized_end=231
  _globals['_MODULECONFIG']._serialized_start=234
  _globals['_MODULECONFIG']._serialized_end=391
  _globals['_GOLANGBINDING']._serialized_start=393
  _globals['_GOLANGBINDING']._serialized_end=487
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from pyinjective.proto.cosmos.gov.v1 import query_pb2 as cosmos_dot_gov_dot_v1_dot_query__pb2


class QueryStub(object):
    """Query defines the gRPC querier service for gov module
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.Constitution = channel.unary_unary(
                '/cosmos.gov.v1.Query/Constitution',
                request_serializer=cosmos_dot_gov_dot_v1_dot_query__pb2.QueryConstitutionRequest.SerializeToString,
                response_deserializer=cosmos_dot_gov_dot_v1_dot_query__pb2.QueryConstitutionResponse.FromString,
                _registered_method=True)
        self.Proposal = channel.unary_unary(
                '/cosmos.gov.v1.Query/Proposal',
                request_serializer=cosmos_dot_gov_dot_v1_dot_query__pb2.QueryProposalRequest.SerializeToString,
                response_deserializer=cosmos_dot_gov_dot_v1_dot_query__pb2.QueryProposalResponse.FromString,
                _registered_method=True)
        self.Proposals = channel.unary_unary(
                '/cosmos.gov.v1.Query/Proposals',
                request_serializer=cosmos_dot_gov_dot_v1_dot_query__pb2.QueryProposalsRequest.SerializeToString,
                response_deserializer=cosmos_dot_gov_dot_v1_dot_query__pb2.QueryProposalsResponse.FromString,
                _registered_method=True)
        self.Vote = channel.unary_unary(
                '/cosmos.gov.v1.Query/Vote',
                request_serializer=cosmos_dot_gov_dot_v1_dot_query__pb2.QueryVoteRequest.SerializeToString,
                response_deserializer=cosmos_dot_gov_dot_v1_dot_query__pb2.QueryVoteResponse.FromString,
                _registered_method=True)
        self.Votes = channel.unary_unary(
                '/cosmos.gov.v1.Query/Votes',
                request_serializer=cosmos_dot_gov_dot_v1_dot_query__pb2.QueryVotesRequest.SerializeToString,
                response_deserializer=cosmos_dot_gov_dot_v1_dot_query__pb2.QueryVotesResponse.FromString,
                _registered_method=True)
        self.Params = channel.unary_unary(
                '/cosmos.gov.v1.Query/Params',
                request_serializer=cosmos_dot_gov_dot_v1_dot_query__pb2.QueryParamsRequest.SerializeToString,
                response_deserializer=cosmos_dot_gov_dot_v1_dot_query__pb2.QueryParamsResponse.FromString,
                _registered_method=True)
        self.Deposit = channel.unary_unary(
                '/cosmos.gov.v1.Query/Deposit',
                request_serializer=cosmos_dot_gov_dot_v1_dot_query__pb2.QueryDepositRequest.SerializeToString,
                response_deserializer=cosmos_dot_gov_dot_v1_dot_query__pb2.QueryDepositResponse.FromString,
                _registered_method=True)
        self.Deposits = channel.unary_unary(
                '/cosmos.gov.v1.Query/Deposits',
                request_serializer=cosmos_dot_gov_dot_v1_dot_query__pb2.QueryDepositsRequest.SerializeToString,
                response_deserializer=cosmos_dot_gov_dot_v1_dot_query__pb2.QueryDepositsResponse.FromString,
                _registered_method=True)
        self.TallyResult = channel.unary_unary(
                '/cosmos.gov.v1.Query/TallyResult',
                request_serializer=cosmos_dot_gov_dot_v1_dot_query__pb2.QueryTallyResultRequest.SerializeToString,
                response_deserializer=cosmos_dot_gov_dot_v1_dot_query__pb2.QueryTallyResultResponse.FromString,
                _registered_method=True)


class QueryServicer(object):
    """Query defines the gRPC querier service for gov module
    """

    def Constitution(self, request, context):
        """Constitution queries the chain's constitution.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Proposal(self, request, context):
        """Proposal queries proposal details based on ProposalID.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Proposals(self, request, context):
        """Proposals queries all proposals based on given status.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Vote(self, request, context):
        """Vote queries voted information based on proposalID, voterAddr.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Votes(self, request, context):
        """Votes queries votes of a given proposal.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Params(self, request, context):
        """Params queries all parameters of the gov module.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Deposit(self, request, context):
        """Deposit queries single deposit information based on proposalID, depositAddr.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Deposits(self, request, context):
        """Deposits queries all deposits of a single proposal.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def TallyResult(self, request, context):
        """TallyResult queries the tally of a proposal vote.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_QueryServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'Constitution': grpc.unary_unary_rpc_method_handler(
                    servicer.Constitution,
                    request_deserializer=cosmos_dot_gov_dot_v1_dot_query__pb2.QueryConstitutionRequest.FromString,
                    response_serializer=cosmos_dot_gov_dot_v1_dot_query__pb2.QueryConstitutionResponse.SerializeToString,
            ),
            'Proposal': grpc.unary_unary_rpc_method_handler(
                    servicer.Proposal,
                    request_deserializer=cosmos_dot_gov_dot_v1_dot_query__pb2.QueryProposalRequest.FromString,
                    response_serializer=cosmos_dot_gov_dot_v1_dot_query__pb2.QueryProposalResponse.SerializeToString,
            ),
            'Proposals': grpc.unary_unary_rpc_method_handler(
                    servicer.Proposals,
                    request_deserializer=cosmos_dot_gov_dot_v1_dot_query__pb2.QueryProposalsRequest.FromString,
                    response_serializer=cosmos_dot_gov_dot_v1_dot_query__pb2.QueryProposalsResponse.SerializeToString,
            ),
            'Vote': grpc.unary_unary_rpc_method_handler(
                    servicer.Vote,
                    request_deserializer=cosmos_dot_gov_dot_v1_dot_query__pb2.QueryVoteRequest.FromString,
                    response_serializer=cosmos_dot_gov_dot_v1_dot_query__pb2.QueryVoteResponse.SerializeToString,
            ),
            'Votes': grpc.unary_unary_rpc_method_handler(
                    servicer.Votes,
                    request_deserializer=cosmos_dot_gov_dot_v1_dot_query__pb2.QueryVotesRequest.FromString,
                    response_serializer=cosmos_dot_gov_dot_v1_dot_query__pb2.QueryVotesResponse.SerializeToString,
            ),
            'Params': grpc.unary_unary_rpc_method_handler(
                    servicer.Params,
                    request_deserializer=cosmos_dot_gov_dot_v1_dot_query__pb2.QueryParamsRequest.FromString,
                    response_serializer=cosmos_dot_gov_dot_v1_dot_query__pb2.QueryParamsResponse.SerializeToString,
            ),
            'Deposit': grpc.unary_unary_rpc_method_handler(
                    servicer.Deposit,
                    request_deserializer=cosmos_dot_gov_dot_v1_dot_query__pb2.QueryDepositRequest.FromString,
                    response_serializer=cosmos_dot_gov_dot_v1_dot_query__pb2.QueryDepositResponse.SerializeToString,
            ),
            'Deposits': grpc.unary_unary_rpc_method_handler(
                    servicer.Deposits,
                    request_deserializer=cosmos_dot_gov_dot_v1_dot_query__pb2.QueryDepositsRequest.FromString,
                    response_serializer=cosmos_dot_gov_dot_v1_dot_query__pb2.QueryDepositsResponse.SerializeToString,
            ),
            'TallyResult': grpc.unary_unary_rpc_method_handler(
                    servicer.TallyResult,
                    request_deserializer=cosmos_dot_gov_dot_v1_dot_query__pb2.QueryTallyResultRequest.FromString,
                    response_serializer=cosmos_dot_gov_dot_v1_dot_query__pb2.QueryTallyResultResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'cosmos.gov.v1.Query', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))
    server.add_registered_method_handlers('cosmos.gov.v1.Query', rpc_method_handlers)


 # This class is part of an EXPERIMENTAL API.
class Query(object):
    """Query defines the gRPC querier service for gov module
    """

    @staticmethod
    def Constitution(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/cosmos.gov.v1.Query/Constitution',
            cosmos_dot_gov_dot_v1_dot_query__pb2.QueryConstitutionRequest.SerializeToString,
            cosmos_dot_gov_dot_v1_dot_query__pb2.QueryConstitutionResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def Proposal(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/cosmos.gov.v1.Query/Proposal',
            cosmos_dot_gov_dot_v1_dot_query__pb2.QueryProposalRequest.SerializeToString,
            cosmos_dot_gov_dot_v1_dot_query__pb2.QueryProposalResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def Proposals(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/cosmos.gov.v1.Query/Proposals',
            cosmos_dot_gov_dot_v1_dot_query__pb2.QueryProposalsRequest.SerializeToString,
            cosmos_dot_gov_dot_v1_dot_query__pb2.QueryProposalsResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def Vote(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/cosmos.gov.v1.Query/Vote',
            cosmos_dot_gov_dot_v1_dot_query__pb2.QueryVoteRequest.SerializeToString,
            cosmos_dot_gov_dot_v1_dot_query__pb2.QueryVoteResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def Votes(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/cosmos.gov.v1.Query/Votes',
            cosmos_dot_gov_dot_v1_dot_query__pb2.QueryVotesRequest.SerializeToString,
            cosmos_dot_gov_dot_v1_dot_query__pb2.QueryVotesResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def Params(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/cosmos.gov.v1.Query/Params',
            cosmos_dot_gov_dot_v1_dot_query__pb2.QueryParamsRequest.SerializeToString,
            cosmos_dot_gov_dot_v1_dot_query__pb2.QueryParamsResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def Deposit(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/cosmos.gov.v1.Query/Deposit',
            cosmos_dot_gov_dot_v1_dot_query__pb2.QueryDepositRequest.SerializeToString,
            cosmos_dot_gov_dot_v1_dot_query__pb2.QueryDepositResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def Deposits(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/cosmos.gov.v1.Query/Deposits',
            cosmos_dot_gov_dot_v1_dot_query__pb2.QueryDepositsRequest.SerializeToString,
            cosmos_dot_gov_dot_v1_dot_query__pb2.QueryDepositsResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def TallyResult(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/cosmos.gov.v1.Query/TallyResult',
            cosmos_dot_gov_dot_v1_dot_query__pb2.QueryTallyResultRequest.SerializeToString,
            cosmos_dot_gov_dot_v1_dot_query__pb2.QueryTallyResultResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)
